package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0````````````(`*``!````\!H!`#0```!8O````@0`!30`(``(
M`"@`'``;``$``'",N```C+@!`(RX`0`(````"`````0````$````!@```#0`
M```T``$`-``!```!`````0``!0````0````#````-`$``#0!`0`T`0$`&0``
M`!D````$`````0````$````````````!`````0"8N```F+@```4```````$`
M`0```)BX``"8N`(`F+@"`%@"``"<$@``!@```````0`"````I+@``*2X`@"D
MN`(`&`$``!@!```&````!`````0```!0`0``4`$!`%`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!`````O;&EB+VQD
M+6QI;G5X+6%R;6AF+G-O+C,`````!````!`````!````1TY5```````"````
M!@```"`````$````%`````,```!'3E4`-I#4\:[P^5FDU;I6(XQP7Y%B\)IA
M````!0```"`````*````H!(`"`)$$2```D``5@!P&,((`#`(`!41```0`@`H
M`````````$@"(`H`"@`$A`.H0`A%8&D`A`D^0CR7``$`""18@`0)8`R3>`E"
M6@!``$```0!""0!`@(S`A```$)`0@PD`"`$0@(%`0,()@"Q`F`)!`"``(`0)
M@)0!I`Z7=D`%``````````8````'````"0`````````````````````````*
M````#`````X````0````$0```!(````4````%P`````````9````````````
M```:````'0```!X`````````(@```",````D`````````"4````F````*@``
M```````L```````````````M````+@```"\````P`````````#0````U````
M`````#D``````````````#H````]````/@`````````_````0````$(```!$
M````1P````````!*````2P```$P```!-`````````$X`````````````````
M``````````````````!/````4`````````!2`````````%0```!6````6```
M``````````````````````!9````70````````!?`````````&$`````````
M8P```&0``````````````&8```!G````:0```&H```!M````7Y:3'*-:[Y!6
MVY,<PXZ'_PTZEPO2402$@72"#7KP2FM]08[%=E0\E,T_#*_W(\X@B0=PTR!T
ML`+59-1\9J_,9BY./?;;]P!>!J2'_P&O-.BQ2)WGSDJN_\[>1RWAIP(*XT?&
M`<8.X#T^?I9\[#^0`FUSA<7%B06089CO$@$C^:2=NY,<0D75[%#N$>.&^9R!
M?>T1#[J5DQQ;FCL/04V=?*?=HVM9[Y=Y.?*+'`P4XIX$,J6%H@+V&=O-XY[[
MH6Q@ZM/O#L@Y0!\R8MOMN8WQ#NG[P\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0
MX2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4:+KCDGPA_^0.BIC=PFYZ:?J+V357DZT$
M8C?C\,%#\N_(WX4@3U>DFY;%N9Q`4!M]7S&X@@V^VE<;LP&+;[S02WUW;^-P
M:@E#UI\BQZ@A8F0'?JF<FV+0^H+L+/:+:W^:?(;PEGS1GRS\[@M1^?/;TQV0
M=8(-0V9+$`5LLLT\K3D-%^I:\:/@^TGB5\085Y):4OW2[P]NQ=\??)`0Z2W?
M_D@NQ9NVWJO*G\G5LG$`````````````````````$0``````````````(```
M`"T``````````````"`````\```````````````@````4```````````````
M(````)D#`````````````!(```!<`@`````````````2````\P(`````````
M````$@```-<"`````````````!(```":!```X+H"```````@`!<`S0$`````
M````````$@```-`"`````````````!(```"]`0``\!4!```````2````)@4`
M`+QW`0`X````$@`-``,$``#PN@(``````!``&`"*`@`````````````2````
MM0(`````````````$@```-H$``#LN@(`!````!$`%P`V`P`````````````2
M````0@4``+!S`0"8`P``$@`-`'\$``"090$`'`$``!(`#0"@`P``````````
M```2````FP(`````````````$@```$<#`````````````!(````2!```-,L"
M```````0`!@`#P$`````````````$@```%T$`````````````!(```"+!```
MR&D!`.@)```2``T`M`0``(QB`0#L````$@`-`'($``!H90$`*````!(`#0#"
M`@`````````````2````A0(`````````````$@```)8!`````````````!(`
M```C`P`````````````2````LP,``/"Z`@`$````(0`8`$0"````````````
M`!(```!+`@`````````````2````Y0(`````````````$@```/`#``#PN@(`
M`````!``%P```P`````````````2````G@```"08`0``````$@```,H"````
M`````````!(```!K`P`````````````2````/@(`````````````$@```&0"
M`````````````!(```"T`P``\+H"``0````A`!@`'00``#3+`@``````$``8
M`$`#```(NP(`!````!$`&``J!```<'@!``0````2``T`H0$`````````````
M$@```&\!`````````````!(```#*!```#'@!`&0````2``T`!@4``-AH`0#P
M````$@`-`#0$``!T>`$``````!(`#@"D`@`````````````2````G@0``/`:
M`0``````$@`-`/,$``!8%0$``````!(`"P"^```````````````2````%0,`
M````````````$@````(!```$NP(``0```!$`&`#>`@`````````````2````
MI00``'QX`0`$````$0`/`/<#``#PN@(``````!``&`!R`P`````````````2
M````B@,`````````````$@```&H``````````````!(````<`0``````````
M```2````\00```1B`0`T````$@`-`#@!`````````````!(````E!```-,L"
M```````0`!@`^00``'QC`0#L`0``$@`-`-,``````````````!(```!S`@``
M```````````2````AP``````````````$@```"H"`````````````!(```"O
M`0`````````````2````X0``````````````$@```/,``````````````!(`
M```M`0```+L"``0````1`!@`L@,``/"Z`@`$````$0`8`&$!````````````
M`!(```#L`@`````````````2````$00``#3+`@``````$``8`!@%``!D:`$`
M7````!(`#0"O```````````````2````+@,`````````````$@```)@$``#@
MN@(``````!``%P!\`P`````````````2````T`,``/BZ`@`$````$0`8`$L$
M``#`:`$`&````!(`#0#K`0`````````````2````V`$`````````````$@``
M`*T#``"X&`$`-`(``!(`#0`]`0`````````````2````5P,`````````````
M$@```$X#`````````````!(```#V`0``#+L"`!,````1`!@`#@,`````````
M````$@```/H"`````````````!(```"2`@`````````````2````Y`$`````
M````````$@```)(#`````````````!(```#D!```K&8!`+@!```2``T`7@,`
M````````````$@```$(!`````````````!(```"\`@`````````````2````
M9@0``$AW`0!T````$@`-`'@``````````````!(```!_`0`````````````2
M````.@0``'AC`0`$````$@`-`(@!`````````````!(```!.`0``K!<!````
M```2`````&QI8G!E<FPN<V\N-2XR,`!?251-7V1E<F5G:7-T97)434-L;VYE
M5&%B;&4`7U]G;6]N7W-T87)T7U\`7TIV7U)E9VES=&5R0VQA<W-E<P!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES7W1E<FT`4&5R;%]S>7-?
M:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?>`!097)L7V%T9F]R:U]L;V-K
M`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?
M<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4&5R;%]S=E]S971P=FX`4$Q?9&]?
M=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H<E]K
M97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C:P!0
M97)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L7V1O
M=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H
M`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO
M8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB;2YS
M;RXV`&QI8G!T:')E860N<V\N,`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E
M`&]P96XV-`!?7V5R<FYO7VQO8V%T:6]N`&QS965K-C0`<F5A9`!L:6)C+G-O
M+C8`7U]R96=I<W1E<E]A=&9O<FL`97AI=`!S=')N8VUP`%]?<W1R9'5P`&-L
M;W-E9&ER`%]?<W1A8VM?8VAK7V9A:6P`=6YL:6YK`&UK9&ER`')E86QL;V,`
M86)O<G0`;65M8VAR`&=E='!I9`!S=')T;VL`<W1R;&5N`&UE;7-E=`!S=')S
M='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`7U]S=')N8W!Y7V-H:P!?
M7VQX<W1A=#8T`&]P96YD:7(`7U]X<W1A=#8T`'-T9&5R<@!G971U:60`<F5A
M9&QI;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?
M<W!R:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R
M=%]M86EN`%]?96YV:7)O;@!L9"UL:6YU>"UA<FUH9BYS;RXS`%]?<W1A8VM?
M8VAK7V=U87)D`&QI8F-R>7!T+G-O+C$`7V5D871A`%]?8G-S7W-T87)T`%]?
M8G-S7W-T87)T7U\`7U]B<W-?96YD7U\`7U]E;F1?7P!?96YD`%]?;&EB8U]C
M<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E
M='!W=6ED`'!A<E]C;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C
M=7)R96YT7V5X96-?<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A
M<E]I;FET7V5N=@!X<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?96YV7V-L96%N`%A37TEN=&5R;F%L<U]005)?0TQ%05)35$%#
M2P!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT```````````````"
M``,``@`"``$````"`````0`!``(``@`!``(``0`!``(``@`"``$````"``$`
M`0`!``(``@````(``@`#``,``@`!``(````"``(``P`#``(``0`"``$`````
M``$``0`!``(``0`!`````@````(``0`!``(``@```````0````$``0````(`
M```#`````````````@````(``0`!`````@`!``(`!``!```````!``(``@`"
M`````@`"``(``@`"``$``@````(``0```````0`````````!``$`O`,``!``
M```@````%&EI#0``!`!8!0````````$``0`:`@``$````"`````4:6D-```#
M`%@%`````````0`!`&D"```0`````````!1I:0T```(`6`4```````#<N@(`
M%0(``/"Z`@`43P``^+H"`!18````NP(`%$X```2[`@`4.P``"+L"`!0O```,
MNP(`%&```,BY`@`6!P``S+D"`!8%``#0N0(`%AH``-2Y`@`6+```V+D"`!87
M``#<N0(`%D```."Y`@`670``Y+D"`!9'``#HN0(`%F$``.RY`@`67@``\+D"
M`!8,``#TN0(`%F(``/BY`@`65```_+D"`!9$````N@(`%CH```2Z`@`6-@``
M"+H"`!9(```,N@(`%A```!"Z`@`6'@``%+H"`!8Q```8N@(`%E```!RZ`@`6
M7P``(+H"`!9G```DN@(`%DP``"BZ`@`66@``++H"`!8&```PN@(`%FX``#2Z
M`@`66P``.+H"`!95```\N@(`%B,``$"Z`@`69```1+H"`!85``!(N@(`%C(`
M`$RZ`@`6`@``4+H"`!8(``!4N@(`%A\``%BZ`@`6)0``7+H"`!9K``!@N@(`
M%BH``&2Z`@`6&0``:+H"`!8D``!LN@(`%E<``'"Z`@`6.0``=+H"`!9C``!X
MN@(`%B```'RZ`@`6:0``@+H"`!91``"$N@(`%F\``(BZ`@`600``C+H"`!9H
M``"0N@(`%@H``)2Z`@`6)P``F+H"`!9"``"<N@(`%@L``*"Z`@`690``I+H"
M`!8\``"HN@(`%DL``*RZ`@`6*```L+H"`!8_``"TN@(`%DT``+BZ`@`6;```
MO+H"`!9)``#`N@(`%A(``,2Z`@`6#P``R+H"`!8I``#,N@(`%BL``-"Z`@`6
M(0``U+H"`!86``#8N@(`%DH```A`+>ER`0#K"("]Z`3@+>4$X)_E#N"/X`CP
MON5(I`$``,:/XAK*C.)(]+SE`,:/XAK*C.)`]+SE`,:/XAK*C.(X]+SE`,:/
MXAK*C.(P]+SE`,:/XAK*C.(H]+SE`,:/XAK*C.(@]+SE`,:/XAK*C.(8]+SE
M`,:/XAK*C.(0]+SE`,:/XAK*C.((]+SE`,:/XAK*C.(`]+SE`,:/XAK*C.+X
M\[SE`,:/XAK*C.+P\[SE`,:/XAK*C.+H\[SE`,:/XAK*C.+@\[SE`,:/XAK*
MC.+8\[SE`,:/XAK*C.+0\[SE`,:/XAK*C.+(\[SE`,:/XAK*C.+`\[SE`,:/
MXAK*C.*X\[SE`,:/XAK*C.*P\[SE`,:/XAK*C.*H\[SE`,:/XAK*C.*@\[SE
M`,:/XAK*C.*8\[SE`,:/XAK*C.*0\[SE`,:/XAK*C.*(\[SE`,:/XAK*C.*`
M\[SE`,:/XAK*C.)X\[SE`,:/XAK*C.)P\[SE`,:/XAK*C.)H\[SE`,:/XAK*
MC.)@\[SE`,:/XAK*C.)8\[SE`,:/XAK*C.)0\[SE`,:/XAK*C.)(\[SE`,:/
MXAK*C.)`\[SE`,:/XAK*C.(X\[SE`,:/XAK*C.(P\[SE`,:/XAK*C.(H\[SE
M`,:/XAK*C.(@\[SE`,:/XAK*C.(8\[SE`,:/XAK*C.(0\[SE`,:/XAK*C.((
M\[SE`,:/XAK*C.(`\[SE`,:/XAK*C.+X\KSE`,:/XAK*C.+P\KSE`,:/XAK*
MC.+H\KSE`,:/XAK*C.+@\KSE`,:/XAK*C.+8\KSE`,:/XAK*C.+0\KSE`,:/
MXAK*C.+(\KSE`,:/XAK*C.+`\KSE`,:/XAK*C.*X\KSE`,:/XAK*C.*P\KSE
M`,:/XAK*C.*H\KSE`,:/XAK*C.*@\KSE`,:/XAK*C.*8\KSE`,:/XAK*C.*0
M\KSE`,:/XAK*C.*(\KSE`,:/XAK*C.*`\KSE`,:/XAK*C.)X\KSE`,:/XAK*
MC.)P\KSE`,:/XAK*C.)H\KSE`,:/XAK*C.)@\KSE`,:/XAK*C.)8\KSE`,:/
MXAK*C.)0\KSE`,:/XAK*C.)(\KSE`,:/XAK*C.)`\KSE`,:/XAK*C.(X\KSE
M`,:/XAK*C.(P\KSE`,:/XAK*C.(H\KSE`````'!`+>D@T$WB%`"-Y1`0C>4,
M((WE%`"-XA`0C>(,((WBE?__Z]01G^74`9_E`2"@X<$7`.O,,9_E`%#3Y0``
M5>/$09\5"0``&F3__^N\(9_E``!0X^@/`N5A```*J$&?Y3K__^L``)3EX/__
MZRU6P.4``)3EW?__ZP`@H.$``)3EWC/2Y0(P@^/>,\+EU___ZQ0PG>556Y_M
M!3"#XE5KG^V0.@?N9WNX[@5[-^[&>[3N$/KQ[MXCT.4!((+CWB/`Y3T``,H#
M`:#A3?__ZQ!`G>4\,9_E-&&?Y10@G>4`X)3E,,&?Y3`1G^4!`%+C`%"@X00`
MD^4$,*#C!,"%Y0P0A>4`X(7E!!"$P@@`A>7P7P;E]#\&Y0)!A,`,P(7"`P``
MV@3@D>0$`%'A!."LY?O__QH-X8+B`,"@XP#`C>4%,*#AZ`\6Y0,@@N+0$)_E
M#L&%YW#__^NT,)_E`$!0X@T```KH#Q;E#O__ZQP0C>*P`)_E3A``ZY10G^4`
M`%#C"0``"N@/%N7T_O_K7/__ZP0`H.$@T(WB<("]Z.@/$^5[___K`$"@X>W_
M_^KL#Q7E``!0XP0```HU%P#K\/__ZF0`G^5D$)_E.___ZQP0C>)<`)_E-A``
MZP``4./L#P7EY___"O/__^H!`*#C'?__ZP``H.$`````````````@/___\]!
MK!<!`"08`0`$NP(``+L"`!C;`@#HN@(`$'P!`!1\`0`X8@$`P'D!`.QZ`0`,
MNP(`7'D!````H.$`L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`
MG^4,,)_E\_[_ZU7__^MP>`$`N!@!``QX`0`4,)_E%""?Y0,PC^`"()/G``!2
MXQ[_+P'N_O_J@)X!`"`!```<,)_E'`"?Y0,P8.`&`%/C'O\OD1`PG^4``%/C
M'O\O`1/_+^'SN@(`\+H"```````D$)_E)`"?Y0$08.!!$:#AH1^!X,$0L.$>
M_R\!$#"?Y0``4^,>_R\!$_\OX?"Z`@#PN@(``````!!`+>D80)_E`##4Y0``
M4^,0@+T8W___ZP$PH.,`,,3E$("]Z!^[`@`(0"WI)`"?Y0`PD.4``%/C`0``
M&@A`O>C@___J$#"?Y0``4^/Z__\*,_\OX?C__^J@N`(``````/!/+>F[WTWB
M.,"`XFC@C>)X8(#B*`"-Y2!@C>7PH\WA@@"<Z`C`C.(0X([B!S2@X0`PC>4!
MA*#A`#"@XPPPC>7_*`CB`#"@XR%$H.'X(<WA`#"@XQ0PC>78(<WA(:R@X0=,
MA.$!'*#A`2""X2>\H.'_#`3B`!"@XP2PC>7X`<WAT`#-X0>DBN$G5*#A_P@`
MX@=\H.$`$*#C!P"`X0!@H.$!<*#AV`'-X0A0C>40L(WE`@"`X0,0@>$`(*#A
M`3"@X?\`"N(`$*#C`"""X0$P@^'8`,WA`!"@XP%PA^'_#`#B`&"&X08`H.$'
M$*#AT&'-X0!PH.,'$('A_V`&X@8`@.$@8)WE\"%.X08`7.'X`$[APO__&LC`
MC>*@`(WB<!"-XF#@C>+@@(WB0)"@X]@@X.'80.SAV&#AX?!@S>$$8"+@!7`C
MX`8@H.$',*#AT&#-X=A`[N$"8";@!&`FX`-P)^`%<"?@IJ^@X09`EN"'H(KA
M!&"*X08@H.$`,*#C`9!9XO@@Z.'H__\:*."=Y0`0H./0(,[AV('.X=A@SN$"
M0*#A`U"@X0`@H.,`,*#C\(/-X?@@S>'0@<[AT"+.X:3-H.$(P(WE^('-X0*@
MH.$(@)WE`["@X=@FS>&%PHCA","-Y?"ES>&ES:#A`J":X`S`C>4#L*O@"B"@
MX0LPH.'8H,WAA`*@X?!`S>$`H(KA"`V?Y09`H.$"`)#@`Q"AX-@AS>$'4*#A
M\`'-X=!CS>$$@*#A!9"@X0*`".`#D`G@T"'-X00`QN$%$,?A`&"@XP!PH.,*
M()+@"`"`X23!H.'X8,WA`#"CX@C`C>4`H)+@"1"!X0&PH^`(,)WE!""@X04_
M@^$(,(WE!3"@X27!H.'X),WA`""@XP`PH.,*`*#A\"'-X0S`C>4+$*#AJCV@
MX1`PC>4$;Z#AV$#-X?@"S>$0P)WE`!"@XP9`A.&!PHSAT(?-X00@H.$0P(WE
MT$#-X0!PH.,',*#A!&"@X05PH.'P(LWA`F`&X`-P!^#8(<WABJ*@X01`PN$%
M4,/AT"/-X0@@DN`),*/@`Y"@X:$]H.$4,(WE`H"@X04PA^$$((;A`D"@X0-0
MH.$`(*#C`#"@X]AKG^7X(,WAT"'-X0A@EN``<*#C"7"GX`H@@N$&H)3@!["E
MX-!`S>$"H)K@`+"KXB3!H.$(P(WE"""=Y27!H.$%/X+A"#"-Y0S`C>4$;Z#A
MV$#-X?BCS>$*(*#A!D"$X=AGS>$*@*#AJLV@X?A@S>$`<*#C!["@X=ABS>$$
MH*#A`)"@XP1@!N`+<`?@V$#-X?!DS>'88<WA^*+-X="BS>$$8);@!D"@X3!K
MG^4%<*?@!U"@X01@EN``<*#C!7"GX(G"C.'X8,WAT&3-X1#`C>6IS:#A%,"-
MY0"@RN$!L,OA"F"&X0MPA^'0H<WAB(*@X0DPH.$(H(KAV(#-X2!!H.$!3X3A
M!H"8X``?H.$($(WE!Y"IX``0H.,*8)C@`;"@X0!PJ>(``*#C`!"@XP:@H.'0
MB,WA#$"-Y?!AS>'88,WA^`#-X90*G^6J':#A"!"-Y0@`D.``$*#C"1"AX-B#
MS>$$8(;A!D"@X0!0H.,&@`C@!9`)X/A#S>$(0*#A"5"@X=""S>$(P)WEBF*@
MX0"`F.`!D*G@V`+-X8O"C.$(P(WE`@#`X0,0P>&KS:#A#,"-Y?""S>$`@(3A
M`9"%X0@`H.'80,WA"1"@X=""S>$&0(3A`("8X"(!H.$!D*G@`P^`X01@F.`"
M/Z#A"#"-Y0P`C>782,WA`'"IX@:`H.$'D*#AV&#-X?!"S>$`(*#C`#"@XP!@
MAN'0`LWA^"#-X0`PH..X*9_E`W"@X:@]H.$(,(WE`""2X``PH.,!,*/@T`'-
MX?!DS>'XA<WA!@``X`<0`>#88LWA`)"@XPC`G>4"8);@`W"GX(G"C.'P8<WA
MV&/-X0C`C>6(0J#A"F#&X0MPQ^$&`(#A!Q"!X=!AS>$!,*#AJ1V@X0P0C>4`
M8);@V`#-X0-PI^``(*#C`#"@XP0`@.'P(<WA`""6X"HQH.$0,(WE`#"GX@,0
MH.$0,)WE`@"@X0L_@^$0,(WE*S&@X10PC>4*3Z#A`J"@X=`AS>'0:<WA\`;-
MX00@@N$"0*#A``"@XP`0H.,`4*#CT"B?Y:H]H.'X`,WA\$+-X0@PC>4&()+@
M`#"@X]@%S>$',*/@T&+-X0C`G>4`L*#C!@``X`<0`>#88\WAB\*,X0C`C>4"
M8);@`W"GX(I"H.'P8<WAT&3-X0`@H.,`4*#C"&#&X0EPQ^$&`(#A!Q"!X=!A
MS>$!,*#AJQV@X0P0C>4`8);@V`#-X0-PI^``,*#C!`"`X?`AS>$`();@*#&@
MX1`PC>4`,*?B`Q"@X1`PG>4"`*#A"3^#X1`PC>4I,:#A%#"-Y0A/H.$"@*#A
MT"'-X=AIS>'X!<WA!"""X0)`H.$``*#C`!"@X^@GG^6H/:#A^`#-X?A"S>$(
M,(WE!B"2X``PH.,',*/@T`;-X=ABS>$`D*#C","=Y08``.`'$`'@T&3-X8G"
MC.$(P(WE`F"6X`-PI^``(*#C\&'-X=!BS>&(0J#A`%"@XPI@QN$+<,?A!@"`
MX0<0@>'08<WA`3"@X:D=H.$`8);@`W"GX``PH.,,$(WE\"'-X=@`S>$J,:#A
M$#"-Y1`0G>4$`(#A`""6X`L?@>$0$(WE`#"GXBL1H.$4$(WE"D^@X?`DS>$"
MH*#AT"'-X=!JS>$``*#C!"""X0)`H.$`$*#C"">?Y:H]H.'X`,WA^$/-X0@P
MC>4&()+@`#"@X]@%S>$',*/@V&/-X0"PH.,(P)WE!@``X`<0`>#08LWAB\*,
MX0C`C>4"8);@`W"GX(I"H.'P8<WAV&+-X0`@H.,`4*#C"&#&X0EPQ^$&`(#A
M!Q"!X=!AS>$!,*#AJQV@X0P0C>4`8);@V`#-X0-PI^``,*#C!`"`X?`AS>$`
M();@*#&@X1`PC>4`,*?B`Q"@X1`PG>4"`*#A"3^#X1`PC>4I,:#A%#"-Y0A/
MH.$"@*#AT"'-X=AJS>'X!<WA!"""X0)`H.$``*#C`!"@XR`FG^6H/:#A^`#-
MX08@DN`(,(WE\$+-X0`PH./0!,WA!S"CX-!BS>$(P)WE`)"@XP8``.`'$`'@
MV&+-X8G"C.$(P(WE`F"6X`-PI^``(*#C\&'-X=ACS>&(0J#A`%"@XPI@QN$+
M<,?A!@"`X0<0@>'08<WA`3"@X:D=H.$`8);@`W"GX``PH.,,$(WE\"'-X=@`
MS>$J,:#A$#"-Y1`0G>4$`(#A`""6X`L?@>$0$(WE`#"GXBL1H.$4$(WE"D^@
MX?`DS>$"H*#AT"'-X=!KS>$``*#C!"""X0)`H.$`$*#C0"6?Y:H]H.'X`,WA
M^$+-X0@PC>4&()+@`#"@XP<PH^#8!<WAV&+-X0"PH.,(P)WE!@``X`<0`>#8
M8\WAB\*,X0C`C>4"8);@`W"GX``@H./P8<WAT&+-X8I"H.$`4*#C"&#&X0EP
MQ^$&`(#A!Q"!X=!AS>$!,*#AJQV@X0!@EN`#<*?@`#"@XPP0C>7P(<WAV`#-
MX2@QH.$0,(WE!`"`X0`@EN``,*?B`Q"@X1`PG>4"`*#A"3^#X1`PC>4I,:#A
M%#"-Y0A/H.$"@*#AT"'-X=AKS>'X!<WA!"""X0)`H.$``*#C`!"@XU@DG^6H
M/:#A^`#-X?A#S>$(,(WE!B"2X``PH./0!,WA!S"CX-ACS>$`D*#C","=Y08`
M`.`'$`'@T&+-X8G"C.$(P(WE`F"6X`-PI^``(*#C\&'-X=ABS>&(0J#A`%"@
MXPI@QN$+<,?A!@"`X0<0@>'08<WA`3"@X:D=H.$`8);@`W"GX``PH.,,$(WE
M\"'-X=@`S>$J,:#A$#"-Y1`0G>4$`(#A`""6X`L?@>$`,*?B$!"-Y2L1H.$4
M$(WE"D^@X?`DS>$"H*#AT"'-X=!LS>$``*#C!"""X0)`H.$`$*#C>".?Y:H]
MH.'X`,WA\$+-X08@DN`(,(WE`#"@XP<PH^#8!<WAT&+-X0"PH.,(P)WE!@``
MX`<0`>#88LWAB\*,X0C`C>4"8);@`W"GX(I"H.'P8<WAV&/-X0`@H.,`4*#C
M"&#&X0EPQ^$&`(#A!Q"!X=!AS>$!,*#AJQV@X0P0C>4`8);@V`#-X0-PI^``
M,*#C!`"`X?`AS>$`();@*#&@X1`PC>4`,*?B`Q"@X1`PG>4"`*#A"3^#X1`P
MC>4I,:#A%#"-Y0A/H.$"@*#AT"'-X=ALS>'X!<WA!"""X0)`H.$``*#C`!"@
MXY`BG^6H/:#A^`#-X?A"S>$(,(WE!B"2X``PH.,',*/@T`3-X=ABS>$`D*#C
M","=Y08``.`'$`'@V&/-X8G"C.$(P(WE`F"6X`-PI^``(*#C\&'-X=!BS>&(
M0J#A`%"@XPI@QN$+<,?A!@"`X0<0@>'08<WA`3"@X:D=H.$`8);@`W"GX``P
MH.,,$(WE\"'-X=@`S>$J,:#A$#"-Y1`0G>4$`(#A`""6X`L?@>$0$(WE`#"G
MXBL1H.$4$(WE\"3-X0I/H.$"H*#AT"'-X=!MS>$``*#C!"""X0)`H.$`$*#C
ML"&?Y:H]H.'X`,WA^$/-X0@PC>4&()+@`#"@X]@%S>$',*/@V&/-X0C`G>4`
ML*#C!@``X`<0`>#08LWAB\*,X0C`C>4"8);@`W"GX(I"H.'P8<WAV&+-X0`@
MH.,`4*#C"&#&X0EPQ^$&`(#A!Q"!X=!AS>$!,*#AJQV@X0P0C>4`8);@V`#-
MX0-PI^``,*#C!`"`X?`AS>$`();@*#&@X1`PC>4`,*?B`Q"@X1`PG>4"`*#A
M"3^#X1`PC>4I,:#A%#"-Y0A/H.$"@*#AT"'-X=AMS>'X!<WA!"""X0)`H.$`
M`*#C`!"@X\@@G^6H/:#A^`#-X?!"S>$(,(WE!B"2X``PH.,',*/@T`3-X=!B
MS>$`D*#C","=Y08``.`'$`'@V&+-X8G"C.$(P(WE`F"6X`-PI^``(*#C\&'-
MX=ACS>&(0J#A`%"@XPI@QN$+<,?A!@"`X0<0@>'08<WA`3"@X:D=H.$`8);@
M`W"GX``PH.,,$(WE\"'-X=@`S>$J,:#A$#"-Y1`0G>4$`(#A`""6X`L?@>$0
M$(WE`#"GXBL1H.$4$(WE"D^@X?`DS>$"H*#AT"'-X0(``.J9>8):F7F"6J'K
MV6[0;LWA``"@XP0@@N$"0*#A`!"@XR0@'^6J/:#A^`#-X?A"S>$(,(WE!B"2
MX``PH./8!<WA!S"CX-ABS>$`L*#C","=Y08``.`'$`'@V&/-X8O"C.$(P(WE
M`F"6X`-PI^"*0J#A\&'-X=!BS>$`(*#C"&#&X0EPQ^$&`(#A!Q"!X=!AS>$!
M,*#AJQV@X0P0C>4`8);@V`#-X0-PI^``,*#C!`"`X?`AS>$`();@*#&@X1`P
MC>4`,*?B`Q"@X1`PG>4"`*#A"3^#X1`PC>4I,:#A%#"-Y0A/H.$"@*#AT"'-
MX?@%S>$``*#C`!"@X]ANS>$$((+A^`#-X0(`H.$`$*#C$"$?Y:@]H.$(,(WE
M^`/-X08@DN``,*#CT`3-X0<PH^#88\WA","=Y0"0H.,&``#@!Q`!X-!BS>&)
MPHSA","-Y0)@EN`#<*?@B$*@X?!AS>'88LWA`""@XPI@QN$+<,?A!@"`X0<0
M@>'08<WA`3"@X:D=H.$,$(WE`&"6X-@`S>$#<*?@`#"@XP0`@.'P(<WA`""6
MX"HQH.$0,(WE`#"GX@,0H.$0,)WE`@"@X0L_@^$0,(WE*S&@X10PC>4*3Z#A
M`J"@X=`AS>'P!,WA``"@XP`0H./0;\WA!"""X?@`S>$"`*#A]"$?Y:H]H.$(
M,(WE!B"2X``PH.,',*/@V&7-X0`0H.,`L*#C`&`&X`%P!^#P`LWA!@"@X0<0
MH.'88LWA","=Y8I"H.$"8);@`W"GX(O"C.'P8<WAV&/-X0C`C>4(SZ#A"&#&
MX0EPQ^$&(*#A!S"@X0)@@.$#<('AJQV@X0P0C>4&(*#A!S"@X=!AS>'8`,WA
M`F"6X"@AH.$)+X+A!`"`X0-PI^`,((WE`$"6X-@/S>$`4*?BJ&(?Y0C`C>4$
M@*#A^$7-X0!@EN#80,WA`'"@XP%PI^`&`*#A!Q"@X=!DS>$"0(3A!""@X0`P
MH.,$8`;@`W`'X/@BS>$&(*#A!S"@X=ACS>$`D*#CJ,V@X0!@EN`!<*?@T`+-
MX8G"C.$(P(WE"@#`X0L0P>$!,(/A`"""X:D=H.$,$(WE!@"2X`<0H^#8(,WA
M*L&@X0L_C.&(0J#A$#"-Y00@@N$#4*#A`3R-X@)@D.``<*'BT`##X?ACS>$`
M<*#C`3"@X2L1H.$4$(WE`""@X0<0H.$&`*#AT&'-X0I/H.&@S:#A!&"&X9!#
M'^4%<(?A`D"4X`!0H.,#4*7@V"7-X?!AS>$`<*#C!S`#X/!DS>$&(`+@`W"@
MX8$RC.$(,(WE`F"@X=`BS>&AS:#A#,"-Y00@DN`%,*/@V$+-X8"BH.%"SXWB
M"$#$X0E0Q>$&0(3A!&"2X`=0A>$%<*/@V"#-X?!BS>$H8:#A"B""X="BS>$)
M;X;A*7&@X0*@FN``L*OB"B"@X0LPH.$(3Z#A`)"@X_@ES>$$@(;A"3"@X0:0
MA^$(0*#A"5"@X="!S>'0H,SA\$'-X02`*.!<1!_E`%"@XPI`E.`+4*7@!*"@
MX06PH.'80\WAHFV@X8-BAN$(0"3@!("@X=A"S>&"PJ#A#&"-Y0I`E.`+4*7@
M"*"4X`C`C>4`L*7BV$#-X2#!H.$!SXSA","-Y09`A.$,<*#A$<Z-X@2`FN``
MD*OBT*#,X2'!H.$,P(WEV$#-X0!OH.'X@\WA"`"@X09`A.&H;:#AT('-X0=0
MA>$`$*#C\$+-X02`*.`$11_E`%"@XPI`E.`+4*7@!*"@X06PH.'81<WA@6*&
MX8#"H.$(0"3@!("@X=!$S>$,8(WE","-Y0I`E.`+4*7@"*"4X`"PI>+80,WA
M(H&@X0./B.$CD:#A`C^@X0R`C>4(,(WE!D"$X01@FN#80,WA1L^-X@!PJ^((
M0(3A"5"%X=""S>'0H,SA^$+-X02`*."411_E`%"@XPI`E.`+4*7@!*"@X06P
MH.'80\WA\&3-X08@H.$0P)WE`'"@XPA`)."F;:#AAV*&X02`H.$,0)K@@L*@
MX0Q@C>4(P(WE`%"KX@B@E.``L*7BV$#-X2#!H.$!SXSA!S"@X0C`C>4&0(3A
M#'"@X1+.C>($@)K@`)"KXM"@S.$AP:#A#,"-Y=A`S>$`;Z#A^(/-X0@`H.$&
M0(3AJ&V@X=B"S>$'4(7A`!"@X_!!S>$$@"C@3$8?Y0!0H.,*0)3@"U"EX`2@
MH.$%L*#AT$3-X8%BAN$,8(WE(,"=Y0A`).`$@*#A#$":X(#"H.$(P(WE`%"K
MX@B@E.``L*7BV$#-X2*!H.$#CXCA(Y&@X0(_H.$,@(WE"#"-Y09`A.$$8)K@
MV$#-X4K/C>(`<*OB"$"$X0E0A>'0@<WAT*#,X?!"S>$$@"C@W$8?Y0!0H.,*
M0)3@"U"EX`2@H.$%L*#AV$/-X?!DS>$&(*#A*,"=Y0!PH.,(0"3@IFV@X8=B
MAN$$@*#A#$":X(+"H.$,8(WE","-Y0!0J^((H)3@`+"EXMA`S>$@P:#A`<^,
MX0C`C>4',*#A!D"$X0QPH.$3SHWB!(":X`"0J^+0H,SA(<&@X0S`C>780,WA
M`&^@X?B#S>$(`*#A!D"$X:AMH.'0@LWA!U"%X0`0H./X0LWA!(`HX)1''^4`
M4*#C"D"4X`M0I>`$H*#A!;"@X=!$S>$0P)WE@6*&X0A`).`$@*#A#$":X(#"
MH.$,8(WE","-Y0!0J^((H)3@`+"EXMA`S>$B@:#A`X^(X2.1H.$"/Z#A#("-
MY0@PC>4&0(3A!&":X-A`S>%.SXWB`'"KX@A`A.$)4(7AV(+-X="@S.'P9,WA
M!(`HX/!!S>$H2!_E`%"@XPI`E.`+4*7@!*"@X06PH.'80\WA!B"@X2#`G>4`
M<*#C"$`DX*9MH.&'8H;A!("@X0Q`FN""PJ#A#&"-Y0C`C>4`4*OB"*"4X`"P
MI>+80,WA(,&@X0'/C.$(P(WE!S"@X09`A.$,<*#A!<V-X@2`FN``D*OBT*#,
MX2'!H.$,P(WEV$#-X0!OH.'X@\WA"`"@X09`A.&H;:#AT('-X0=0A>$HP)WE
M\$+-X02`*.#<2!_E`%"@XPI`E.`+4*7@!*"@X06PH.'01,WA`!"@XR.1H.$(
M0"3@@6*&X02`H.$,0)K@@,*@X0Q@C>4(P(WE`%"KX@B@E.``L*7BV$#-X2*!
MH.$#CXCA`C^@X0R`C>4(,(WE!D"$X01@FN#80,WA4L^-X@!PJ^((0(3A"5"%
MX=""S>'0H,SA^$+-X02`*.!L21_E`%"@XPI`E.`+4*7@!*"@X06PH.'80\WA
M!B"@X1#`G>7P9,WA`'"@XPA`)."F;:#AAV*&X02`H.$,0)K@@L*@X0Q@C>4(
MP(WE`%"KX@B@E.``L*7BV$#-X2#!H.$!SXSA!S"@X09`A.$(P(WE#'"@X17.
MC>($@)K@`)"KXM"@S.$AP:#A#,"-Y0`0H.,!4*#A\('-X0!OH.'8`,WA"$"@
MX2#`G>4&`(#A!Q"!X0"`H.$!D*#A``"@XP`0H./X@\WA^`#-X:0=H.$($(WE
MV`+-X0`0H.,(`"#@`&"@X4P*'^4*`)#@"Q"AX`&PH.$($)WE`*"@X842@>$(
M$(WET`3-X0R`FN"ES:#A!@`@X`!@H.$,P(WE`)"KX@:@F.``L*GBV(#-X80"
MH.$BP:#A`\^,X0"`B.$(P(WE"&":X`P0H.%6SXWB`'"KXM"@S.$CP:#A#,"-
MY?!DS>$`<*#C!S"@X0(/H.$&(*#AV&#-X=B#S>$EP:#A`7"'X0!@AN$&`*#A
M!Q"@X0"`*.#P`LWA_`H?Y0`0H.,*`)#@"Q"AX`"@H.$!L*#AT`'-X0>0*>"B
M;:#A"``@X`D0(>"#8H;A\`'-X2@0G>4,8(WE`8":X((2H.$($(WE$!"=Y0"0
MJ^(!H)C@V`#-X201H.$%'X'A"!"-Y0S`C>4&`(#A!&^@X=A`S>$`L*GB`(":
MX`"0J^(!<*#A!D"$X0=0A>$(`*#A^(7-X02`H.$%D*#AT$+-X18>C>*@S:#A
MT*#!X0A`).`$8*#AL$L?Y0`0H.,*0)3@`%"@XPM0I>"!PHSA^(+-X1#`C>4$
MH*#A!;"@X=!$S>$XP)WE`H^@X0R@FN`&0"3@`+"KX@1`FN``4*OBH<V@X13`
MC>7X0,WAT$'-X8!BH.%:SXWB!D"$X=A@S>$BH:#A`Z^*X01@EN``<*?B!D"@
MX0=0H.'08,SA([&@X2#`G>7X8,WA"&"*X=B"S>$*<(OAV*#-X?!AS>$&@"C@
M6&P?Y0!PH.,&H)K@!["KX`I@H.$+<*#AV*7-X?A#S>$`4*#C#&"6X*0MH.$(
MH"K@A2*"X0!PI^*$PJ#A"H"6X`P@C>4(P(WE`)"GX@B@H.$)L*#AV(#-X2!A
MH.$!;X;A`H"(X0B@FN``L*OB"H"@X0N0H.$`+Z#A7L^-X@@`H.'PA,WA(7&@
MX0*`AN'0(<WA!I"'X=B@3.'P@LWA""`BX/B,'^4),"/@"H"8X`"0H.,+D*G@
M"*"@X0FPH.'8@\WA`!"@XZ!MH.$"@"C@`Y`IX"@PG>7X@\WA`X":X(`RH.$(
M,(WE@6*&X3@PG>4,8(WE`)"KX@.@F.#8(,WA`+"IXB2!H.$&((+A`F":X`!P
MJ^(%CXCAT*#,X03/H.$,@(WE^&/-X0C`C>4`<*#C!B"@X0<PH.'88,WA)9&@
MX:)-H.$(8(;A"7"'X0:`H.$'D*#AT&+-X?B"S>$0P)WE"&`FX%B-G^4)<"?@
M"H"8X`"0H.,+D*G@"*"@X0FPH.'0A,WA@T*$X0:`*.`'D"G@@F*@X?B`S>$,
M@)K@","=Y0"0J^(,H)C@!H"$X0"PJ>(@8:#A"$":X`!0J^(!;X;A(7&@X0`?
MH.$,8(WE"!"-Y00`H.'P1,WAV$#-X6+/C>(`$*#C!D"$X0=0A>$$@*#A!9"@
MX=A"S>'8H$SA\('-X0A`)."XC)_E"5`EX`J`F.``D*#C"Y"IX`B@H.$)L*#A
MV(/-X:!MH.&!8H;A!(`HX`60*>"`0J#A^(/-X2!0G>4(0(WE.$"=Y0Q@C>4%
M@)K@`)"KX@2@F.#80,WA`+"IXB*!H.$&0(3A!&":X`!PJ^(#CXCA(Y&@X0(_
MH.$,@(WE"#"-Y?ACS>$`<*#C!D"@X0=0H.'88,WAT*#,X2C`G>4(8(;A"7"'
MX0:`H.$'D*#AT&'-X?""S>&D+:#A"&`FX/R+G^4)<"?@"H"8X`"0H.,+D*G@
M"*"@X0FPH.'0A,WAA2*"X0:`*.`'D"G@A&*@X?B`S>$,@)K@","=Y0"0J^(,
MH)C@!H""X0"PJ>((()K@9L^-X@`PJ^(@8:#A`6^&X2%QH.$`'Z#AV*!,X0(`
MH.$,8(WE"!"-Y?`DS>'8(,WA`!"@XP8@@N$',(/A`H"@X0.0H.'0(LWA^(+-
MX:!MH.$(("+@6(N?Y0DP(^`*@)C@`)"@XPN0J>`(H*#A";"@X=B#S>&!8H;A
M#&"-Y0*`*.`#D"G@$#"=Y?B#S>$#@)K@@#*@X0@PC>4X,)WE`)"KX@.@F.#8
M(,WA`+"IXB2!H.$&((+A`F":X`!PJ^(%CXCAT*#,X03/H.$(P(WE#("-Y?AC
MS>$`<*#C!B"@X0<PH.'88,WA)9&@X2#`G>4(8(;A"7"'X0:`H.$'D*#AV&+-
MX?"!S>&B3:#A"&`FX*"*G^4)<"?@"H"8X`"0H.,+D*G@"*"@X0FPH.'0A,WA
M@T*$X0:`*.`'D"G@@F*@X?B`S>$,@)K@","=Y0"0J^(,H)C@!H"$X0"PJ>(@
M8:#A"$":X`!0J^(!;X;A(7&@X0`?H.$,8(WE"!"-Y00`H.'P1,WAV$#-X1K.
MC>(`$*#C!D"$X0=0A>$$8*#A!7"@X=!!S>'0@,SA\&+-X09`).`$8*#A_$F?
MY0!0H.,(0)3@"5"EX-B#S>$H<)WEH*V@X0=`E.`&@"C@`%"EX@B`E.``D*7B
M@:**X8#"H.$,H(WE","-Y?B"S>'8@,WA(F&@X0-OAN$*@(CAV*+-X2-QH.%J
M/XWB"*":X-"`P^$`L*OB`D^@X?B%S>$`D*#C"3"@X02`AN$&D(?A^*/-X0H@
MH.$)L*#A"*"@X=""S>'01,WA^*+-X0I@B.$&0`3@!&"@X0A`H.'8A<WA"D`$
MX$BIG^4`L*#C"H"8X`N0J>`(H*#A";"@X:+-H.'PI,WA@\*,X0:@A.'01,WA
M","-Y1#`G>4AL:#A#$"4X`!0I>*CS:#A"F"4X`S`C>4`<*7B@L*@X0R`H.'P
M8<WA"&"@X=B`S>%NSXWB(*&@X0&OBN$`3Z#A!H"(X=@`3.$(8*#AT('-X?`!
MS>$$`(KA"A"+X0"@H.,`L*#C!H"8X/B@S>'80LWAJ*V@X0B@C>78H\WA`&"@
MX0%PH.$&`(3A`)"IX@9`!.#X8\WA`*`*X`1@H.'00<WA\(3-X0H`H.$`D*#C
M:*B?Y8D2H.$*0)3@!*"@X:@=@>$(0)WE%!"-Y2`0G>6)0H3A`+"@XPM0I>`(
M0(WE`$"&X0%@FN"I':#A#!"-Y8@2H.$0$(WE`'"EXM`!S>$$H);@V$#-X0"P
MI^(B8:#A!`"`X0"@FN`#;X;A`+"KXB-QH.$"3Z#AT"#,X?BES>$`L*#C\"'-
MX0H@H.$+,*#A!*"&X0:PA^$*`*#A"Q"@X=BCS>'P`LWAHLV@X0!@BN$&0*#A
MT&3-X0`0H.,I<:#A!&`&X`9`H.$*8*#AT*'-X0!@!N"4!Y_E`*":X`&PJ^"#
M$HSA*,"=Y0@0C>4&`(3A@Q*@X:(=@>$`0*#A#`":X!00C>6CS:#A`!"KX@1`
MD.`,P(WE`%"AXH+"H.$0P(WEV*#-X?A"S>'00<WA*&&@X0EOAN$$H(KA"D"@
MX=BBS>$(#Z#A<L^-X@2@FN``L*OBT$+-X0J`H.'PI,WA`*"&X0:PA^$*`(3A
M"F"@X0MPH.$`H*#C`+"@XP"0H./XH,WAJ*V@X0B@C>78I<WA!D`$X/ABS>$`
MH`K@"@"@X=B@3.$$8*#AQ$:?Y8D2H.$$H)K@J!V!X0A`G>44$(WE.!"=Y8E"
MA.$`4*#C!;"KX`A`C>4`0(;A`6":X*D=H.$,$(WEB!*@X1`0C>70`<WA`'"K
MX@2@EN#80,WA(F&@X0-OAN$$`(#A`+"GX@)/H.$`H)K@(W&@X=`@S.$`L*OB
M\"'-X?BES>$`L*#C"B"@X0LPH.$$H(;A!K"'X0H`H.$+$*#AV*+-X?@#S>&B
MS:#A`&"*X09`H.'09,WA`!"@XREQH.$$8`;@!D"@X0I@H.'0H<WA`&`&X/0%
MG^4`H)K@`;"KX(,2C.$@P)WE"!"-Y08`A.&#$J#AHAV!X0!`H.$,`)K@%!"-
MY:/-H.$`$*OB!$"0X`S`C>4`4*'B@L*@X1#`C>78H,WA\$+-X=!!S>$H8:#A
M"6^&X02@BN$*0*#AT*+-X0@/H.%VSXWB!*":X`"PJ^+80\WA"H"@X?"DS>$`
MH(;A!K"'X0H`A.$*8*#A"W"@X0"@H.,`L*#C`)"@X_B@S>&HK:#A"*"-Y=BE
MS>$&0`3@\&+-X0"@"N`*`*#AV*!,X01@H.$D19_EB1*@X02@FN"H'8'A"$"=
MY100C>4H$)WEB4*$X0!0H.,%L*O@"$"-Y0!`AN$!8)K@J1V@X0P0C>6($J#A
M$!"-Y=`!S>$`<*OB!*"6X-A`S>$`L*?B(F&@X00`@.$`H)K@`V^&X0"PJ^(C
M<:#A`D^@X=`@S.'XI<WA`+"@X_`AS>$*(*#A"S"@X02@AN$&L(?A"@"@X0L0
MH.'0HLWAHLV@X0!@BN$&0*#AT&3-X?@"S>$`$*#C!&`&X`9`H.$*8*#AT*'-
MX0!@!N!8!)_E*7&@X0"@FN`!L*O@@Q*,X3C`G>4($(WE!@"$X8,2H.&B'8'A
M`$"@X0P`FN`4$(WEH\V@X0`0J^($0)#@#,"-Y0!0H>*"PJ#A$,"-Y=B@S>'X
M0\WAT$'-X2AAH.$);X;A!*"*X0I`H.'8H\WA"`^@X7K/C>($H)K@`+"KXMA"
MS>$*@*#A\*3-X0"@AN$&L(?A"@"$X0I@H.$+<*#A`*"@XP"PH.,`D*#C^*#-
MX:BMH.$(H(WEV*7-X09`!.#X8\WA`*`*X`H`H.'8H$SA!&"@X81#G^6)$J#A
M!*":X*@=@>$(0)WE%!"-Y2`0G>6)0H3A`%"@XP6PJ^`(0(WE`$"&X0%@FN"I
M':#A#!"-Y8@2H.$0$(WET`'-X0!PJ^($H);@V$#-X0"PI^(B8:#A!`"`X0"@
MFN`#;X;A`+"KXB-QH.$"3Z#AT"#,X?"BS>$`L*#C\"'-X0H@H.$+,*#A!*"&
MX0:PA^$*`*#A"Q"@X=BCS>&BS:#A*5&@X0!@BN$&0*#AT&3-X?`$S>$`$*#C
M!&`&X`9`H.$*8*#AT*'-X0!@!N"T`I_E`*":X`&PJ^"#$HSA*,"=Y0@0C>4&
M`(3A@Q*@X:(=@>$`8*#A#`":X!00C>6CS:#A`!"KXBA!H.$&8)#@#,"-Y0!P
MH>()3X3A@L*@X0@/H.$0P(WE`("$X0"0H./0!,WA^&+-X=!AS>$)<*#A!)"%
MX0E0H.$(0*#A!("`X060@>'P0<WA"$"@X0E0H.'0@LWAV*#-X3C`G>4$@`C@
M!9`)X`:@BN'X@,WA`("@X=`!S>$?'HWB"F"@X=BBS>$`@`C@T`#!X>Q!G^4&
MH)K@`+"KX@!0H.,$`)#@!1"AX`I@H.'P`LWAV`#-X?BBS>&JK:#A"`"`X0!`
MH.'0`LWAAZ**X0R@C>4,`)#@`!"AX@2`D.``D*'BAL*@X0C`C>7P@LWAV(#-
MX2)!H.$#3X3A"H"(X="BS>$C4:#A`@^@X0B@FN``L*OB"B"@X?BCS>$`L*#C
M"S"@X0"@A.$$L(7A"H"@X0N0H.'0`<WA\(+-X=B"S>$*0(#A"U"!X02`".`%
MD`G@,$&?Y?B`S>$`@*#AT`+-X7X?C>(`4*#C`(`(X-``P>&BK:#A@Z**X00`
MD.`%$*'@)U&@X?@"S>'8`,WA0,"=Y0R@C>4(`(#A`$"@X=@"S>$,`)#@`!"A
MX@2`D.``D*'B@L*@X0C`C>7X@LWAV(#-X29!H.$'3X3A"H"(X=BBS>$&#Z#A
M$,"=Y0B@FN``L*OB"F"@X?"DS>$`H(3A!+"%X0J`H.$+D*#AT`+-X?B"S>'8
M@\WA"D"`X0M0@>$$@`C@!9`)X&Q`G^7X@,WA`("@X=@"S>$"'(WB`%"@XP"`
M".#0`,'A`'"@XZ:MH.$$`)#@!1"AX(>BBN'X`\WAV`#-X0R@C>4C4:#A"`"`
MX0!`H.'8`\WA#`"0X``0H>($@)#@`)"AXH;"H.$(P(WE\('-X0(``.JAZ]EN
MW+P;C];!8LK8@,WA(D&@X0-/A.$*@(CAT*'-X0(/H.$(H)K@`+"KX@H@H.'X
MH\WA`+"@XPLPH.$`H(3A!+"%X0J`H.$+D*#AV`+-X?"!S>'0A,WA"D"`X0M0
M@>$$@`C@!9`)X&Q`'^7X@,WA`("@X=`!S>&"'XWB`%"@XP"`".#0`,'AHJV@
MX8.BBN$$`)#@!1"AX"=1H.'P!,WAV`#-X0R@C>4@P)WE"`"`X0!`H.'0!,WA
M#`"0X``0H>($@)#@`)"AXH+"H.$(P(WE\(+-X=B`S>$F0:#A!T^$X0J`B.'0
MHLWA!@^@X2C`G>4(H)K@`+"KX@I@H.'PI,WA`*"$X02PA>$*@*#A"Y"@X=`!
MS>'P@LWAV(/-X0I`@.$+4('A!(`(X`60">`P01_E^(#-X0"`H.'0`LWA(1Z-
MX@!0H.,`@`C@T`#!X0!PH..FK:#A!`"0X`40H>"'HHKA^`/-X=@`S>$,H(WE
M(U&@X0@`@.$`0*#AV`/-X0P`D.``$*'B!("0X`"0H>*&PJ#A","-Y?B"S>'8
M@,WA(D&@X0-/A.$*@(CAV*+-X0(/H.$0P)WE"*":X`"PJ^(*(*#A^*/-X0"P
MH.,+,*#A`*"$X02PA>$*@*#A"Y"@X=`"S>'X@LWAT(3-X0I`@.$+4('A!(`(
MX`60">#\01_E^(#-X0"`H.'8`LWAAA^-X@!0H.,`@`C@T`#!X:*MH.&#HHKA
M!`"0X`40H>`G4:#A\`3-X=@`S>$,H(WE"`"`X0!`H.'0!,WA#`"0X``0H>($
M@)#@`)"AXH+"H.$(P(WE\('-X=B`S>$F0:#A!T^$X0J`B.'0H<WA!@^@X2#`
MG>4(H)K@`+"KX@I@H.'PI,WA`*"$X02PA>$*@*#A"Y"@X=@"S>'P@<WAV(/-
MX0I`@.$+4('A!(`(X`60">"\0A_E^(#-X0"`H.'0`<WA(AZ-X@!0H.,`@`C@
MT`#!X0!PH..FK:#A!`"0X`40H>"'HHKA^`/-X=@`S>$,H(WE(U&@X0@`@.$`
M0*#AV`/-X0P`D.``$*'B!("0X`"0H>*&PJ#A","-Y?""S>'8@,WA(D&@X0-/
MA.$*@(CAT*+-X0(/H.$HP)WE"*":X`"PJ^(*(*#A^*/-X0"PH.,+,*#A`*"$
MX02PA>$*@*#A"Y"@X=`!S>'P@LWAT(3-X0I`@.$+4('A!(`(X`60">"(0Q_E
M^(#-X0"`H.'0`LWABA^-X@!0H.,`@`C@T`#!X:*MH.&#HHKA!`"0X`40H>`G
M4:#A\`3-X=@`S>$,H(WE"`"`X0!`H.'0!,WA#`"0X``0H>($@)#@`)"AXH+"
MH.$(P(WE^(+-X=B`S>$F0:#A!T^$X0J`B.'8HLWA!@^@X1#`G>4(H)K@`+"K
MX@I@H.'PI,WA`*"$X02PA>$*@*#A"Y"@X=`"S>'X@LWAV(/-X0I`@.$+4('A
M!(`(X`60">!(1!_E^(#-X0"`H.'8`LWA(QZ-X@!0H.,`@`C@T`#!X0!PH..F
MK:#A!`"0X`40H>"'HHKA^`/-X=@`S>$,H(WE(Y&@X0@`@.$`0*#AV`/-X2*!
MH.$#CXCA#`"0X``0H>($0)#@`%"AXH;"H.$(P(WE\$'-X=A`S>$"#Z#ACC^-
MX@I`A.'0H<WAT"##X02@FN``L*OB"D"@X?BES>$`H(CA`+"@X]@"S>$+4*#A
M"+")X="$S>$*`(#A"Q"!X0"`".`(!1_E`9`)X`(`D."DS:#A`!"@X_"$S>$#
M$*'@V(+-X84RC.$(,(WET"3-X0J`".#P`<WA""""X0(`H.'0(<WA(,"=Y?BC
MS>$,()+@I<V@X0S`C>6$PJ#A`#"CX@R@H.$``)+@`("@X0H`H.'8H,WA)L&@
MX0?/C.$*`(#A$,"-Y0`0H^(`@)C@##"@X2?!H.$4P(WE`)"AX@G-C>((`*#A
M"1"@X="!S>$&+Z#AT&#,X0*`B.$#D(GA^&#-X0A@H.$)<*#AV(/-X?!BS>'P
M!,WA!J"(X0>PB>'89<WA\('-X2C`G>4*8`;@"W`'X-B@S>'X8\WAT&+-X0!P
MH.,`$*#C!H`(X`QF'^6@+:#A!J":X`>PJ^`*8*#A"W"@X=BCS>&!(H+A#""-
MY0B@BN$*@*#A#*"6X(#"H.$(P(WE`+"GXMA@S>$DP:#A!<^,X0C`C>4(H)K@
M`F"&X0PPH.&2SXWB`+"KX@:`FN``D*OBT*#,X27!H.$,P(WE"&"@X?B%S>'8
M@,WA!"^@X0!PH.,"@(CA`Y")X0@@H.$),*#AT(+-X?@BS>&F3:#A`H`HX+`F
M'^4#D"G@"B"2X``PH.,+,*/@`J"@X0.PH.'0),WAAT*$X0Q`C>4(("+@"3`C
MX/@CS>$0,)WE`X":X(8RH.$(,(WE.#"=Y0"0J^(#H)C@V"#-X0"PJ>(E/HWB
M!"""X0)`FN``4*OB((&@X0&/B.$AD:#A`!^@X="@P^$,@(WE\$3-X0@0C>78
M`,WA`%"@XZ3-H.$(`(#A"1"!X=B"S>'X`\WA!""@X0"`*.!<!Q_E`9`IX`H`
MD.``$*#C"Q"AX`&PH.&%$HSA$!"-Y0"@H.'8!<WAA$*@X2?!H.$(`"#@"1`A
MX`4PH.'X`,WA(!"=Y0S`C>4!@)K@I1V@X100C>4($)WE`)"KX@&@F.#0`<WA
M`+"IXB81H.$$`(#A`(":X`"0J^(''X'A"!"-Y0@`H.'XA<WAV(#-X0%0H.$&
M3Z#A!("(X060B>$(0*#AEA^-X@E0H.'8@\WAT*#!X?!"S>$$@"C@%$@?Y0!0
MH.,*0)3@"U"EX`2@H.$%L*#AT$3-X2C`G>4`$*#CH&V@X0A`)."!8H;A!("@
MX0Q`FN"`PJ#A#&"-Y0C`C>4`4*OB"*"4X`"PI>+80,WA)LZ-XB*!H.$&0(3A
M!&":X`!PJ^(#CXCA(Y&@X0(_H.'0H,SA#("-Y0@PC>4&0*#AV"#-X?!DS>&F
MS:#AI&@?Y0!PH.,'4*#A"F"6X`!PH.,(((+A"3"#X0MPI^#0@LWA!J"@X0>P
MH.'89<WA`H`HX`.0*>`(8";@"7`GX/@BS>&%,HSA^&#-X1`PC>4X,)WEA&*@
MX0.`FN"E/:#A%#"-Y0@PG>4`D*OB`Z"8X-`AS>$@,:#A`3^#X08@@N$AP:#A
M`&^@X0`0H.,``*#C"#"-Y0S`C>7P`<WA`+"IXM@`S>$"@)K@`)"KX@@@H.$#
M<*#AFC^-XOB%S>$'$('A`)"@X]"@P^$&`(#A"3"@X0&0H.&B':#A$!"-Y0"`
MH.'8`LWA^(/-X=!DS>$(`"#@`("@X9@)'^4)$"'@"@"0X`&0H.$`$*#C"Q"A
MX`&PH.$0$)WE"&`FX(,2@>$0$(WE"7`GX"`0G>7X8,WA`8"0X*,=H.$4$(WE
M"!"=Y0"0J^(!H)C@T`'-X22!H.$%CXCA!,^@X0R`C>4(P(WE@F*@X0"PJ>(&
M`(#A)9&@X=A`S>$`8)K@`'"KX@A`A.$)4(7A!@"@X?!DS>$G'HWB!&"@X05P
MH.'80\WAT*#!X0`0H./P8LWA!D`DX*#-H.'89<WA!("@X8'"C.%<2A_E$,"-
MY2C`G>4*0)3@"&`FX`!0H.,+4*7@!H"@X0Q`E."AS:#A%,"-Y0!0I>((H)3@
M`+"EXM!!S>$BP:#A`\^,X8!BH.$(P(WE!D"$X0QPH.&>SXWB!(":X`"0J^+0
MH,SA(\&@X0S`C>4";Z#AV"#-X?B%S>$(0*#A!B""X=QJ'^4',(/A"F"6X`!P
MH..HS:#A"W"GX-""S>$`4*#C!J"@X0>PH.'09,WA^"+-X0*`*.`#D"G@A3*,
MX1`PC>4(8";@.#"=Y0EP)^`#@)K@^&#-X:4]H.$4,(WE"#"=Y0"0J^(#H)C@
M((&@X0"PJ>(!CXCA(9&@X0`?H.$,@(WE"!"-Y=@`S>'0(<WAA&*@X0@`@.$)
M$('A"CV-XMB"S>$&((+A`F":X`!PJ^+0H,/A^`/-X0"`*."4"Q_E\&3-X0H`
MD.``<*#C`9`IX``0H..FS:#A"Q"AX`&PH.&'$HSA$!"-Y0"@H.'8!<WA!B"@
MX27!H.$(`"#@"1`AX(9BH.'X`,WA(!"=Y0S`C>4!@)K@IQV@X100C>4($)WE
M`)"KX@&@F.#0`<WA)!&@X04?@>$($(WE!@"`X0"PJ>($;Z#A`(":X-A`S>$`
MD*OB!S"@X0%PH.&B'XWB"`"@X09`A.'XA<WA!U"%X:C-H.'8@\WAT*#!X0`0
MH./P0LWAT&3-X02`*."!PHSA9$P?Y1#`C>4HP)WE"D"4X`A@)N``4*#C"U"E
MX`:`H.$,0)3@H<V@X13`C>4`4*7B"*"4X`"PI>+00<WA@&*@X2G.C>(&0(3A
M!&":X"*!H.$`<*OB`X^(X2.1H.$"/Z#A#("-Y0@PC>70H,SAV"#-X?!DS>$&
M0*#AILV@X>!L'^4`<*#C!U"@X0I@EN``<*#C""""X0DP@^$+<*?@T(+-X0:@
MH.$'L*#AV&7-X?@BS>$"@"C@`Y`IX(4RC.$0,(WE"&`FX#@PG>4)<"?@`X":
MX/A@S>&E/:#A%#"-Y0@PG>4`D*OB`Z"8X-`AS>&$8J#A(#&@X0$_@^$&((+A
M(<&@X0!OH.$`$*#C``"@XP@PC>4,P(WE\`'-X0"PJ>+8`,WA`H":X`"0J^((
M(*#A`W"@X:8_C>+XA<WA!Q"!X0"0H./0H,/A!@"`X0DPH.$!D*#AHAV@X1`0
MC>4`@*#AV`+-X?B#S>'09,WA"``@X`"`H.$\!Y_E"1`AX`H`D.`!D*#A`!"@
MXPL0H>`!L*#A$!"=Y0A@)N"#$H'A$!"-Y2`0G>4)<"?@`8"0X*,=H.'X8,WA
M%!"-Y0@0G>4`D*OB`:"8X-`!S>$D@:#A!8^(X03/H.$(P(WE#("-Y8)BH.$`
ML*GB!@"`X261H.'80,WA`&":X`!PJ^((0(3A"5"%X?!DS>$&`*#A*AZ-X@1@
MH.$%<*#AV$/-X="@P>$`$*#C\&+-X09`)."@S:#AV&7-X02`H.&!PHSA>$:?
MY1#`C>4HP)WE"D"4X`A@)N``4*#C"U"EX`:`H.$,0)3@H<V@X13`C>4`4*7B
M"*"4X`"PI>+00<WA(L&@X0//C.&`8J#A","-Y09`A.$,<*#AJL^-X@2`FN``
MD*OBT*#,X2/!H.$,P(WE`F^@X=@@S>$(0*#A^(7-X08@@N'X99_E!S"#X0I@
MEN``<*#CJ,V@X0MPI^#0@LWA`%"@XP:@H.$'L*#AT&3-X?@BS>$"@"C@`Y`I
MX(4RC.$0,(WE"&`FX#@PG>4)<"?@`X":X/A@S>&E/:#A%#"-Y0@PG>4`D*OB
M`Z"8X-`AS>$@@:#A`+"IX@&/B.&$8J#A(9&@X0`?H.$,@(WE"!"-Y08@@N$"
M8)K@V`#-X0!PJ^(K/HWB\&3-X="@P^$(`(#A"1"!X=B"S>'X`\WA`'"@XP"`
M*.`X!9_E`9`IX`H`D.``$*#CILV@X0L0H>`!L*#AAQ*,X1`0C>4`H*#AV`7-
MX08@H.&&8J#A"``@X`D0(>`EP:#A^`#-X2`0G>4,P(WE`8":X*<=H.$4$(WE
M"!"=Y0"0J^(!H)C@T`'-X201H.$%'X'A!@"`X0@0C>4`L*GB`(":X`"0J^($
M;Z#AV$#-X0<PH.$!<*#AKA^-X@@`H.'XA<WAJ,V@X=B#S>'0H,'A!D"$X0`0
MH.,'4(7AT&3-X?!"S>$$@"C@@<*,X7!$G^40P(WE*,"=Y0I`E.`(8";@`%"@
MXPM0I>`&@*#A#$"4X*'-H.$4P(WE`%"EX@B@E.``L*7BT$'-X8!BH.$+S8WB
M!D"$X01@FN`B@:#A`'"KX@./B.$CD:#A`C^@X="@S.$,@(WE"#"-Y09`H.'8
M(,WA\&3-X:;-H.'T8Y_E`'"@XP=0H.$*8);@`'"@XP@@@N$),(/A"W"GX-""
MS>$&H*#A!["@X=AES>'X(LWA`H`HX`.0*>"%,HSA$#"-Y0A@)N`X,)WE"7`G
MX`.`FN#X8,WAI3V@X10PC>4(,)WE`)"KX@.@F.#0(<WAA&*@X2`QH.$!/X/A
M!B""X2'!H.$`;Z#A`!"@XP``H.,(,(WE#,"-Y?`!S>$`L*GBV`#-X0*`FN``
MD*OB"""@X0-PH.&R/XWB^(7-X0<0@>$`D*#CT*##X08`@.$),*#A`9"@X:(=
MH.$0$(WE`("@X=@"S>'X@\WAT&3-X0@`(.``@*#A``.?Y0D0(>`*`)#@`9"@
MX0`0H.,+$*'@`;"@X1`0G>4(8";@@Q*!X1`0C>4)<"?@(!"=Y?A@S>$!@)#@
MHQV@X100C>4($)WE`)"KX@&@F.#0`<WA)(&@X06/B.$$SZ#A","-Y0R`C>6"
M8J#A`+"IX@8`@.$ED:#AV$#-X0!@FN``<*OB"$"$X0E0A>$&`*#A\&+-X2T>
MC>($8*#A!7"@X=A#S>'0H,'A`!"@X_!DS>$&0"3@H,V@X=AES>$$@*#A@<*,
MX3Q"G^40P(WE*,"=Y0I`E.`(8";@`%"@XPM0I>`&@*#A#$"4X*'-H.$4P(WE
M`%"EX@B@E.``L*7BT$'-X8!BH.$BP:#A!D"$X02`FN`#SXSA`)"KX@C`C>4,
M<*#A`F^@X2/!H.$`(*#C`#"@X_B%S>$,P(WE\"'-X=@@S>$XP)WE`)"@XP<P
M@^$#L*#AJ#V@X1`PC>6V/XWB!B""X=!@P^$"H*#AF"&?Y?BBS>$"8);@#""6
MX-!DS>$0,)WEJ<V@X0I@)N#0HLWAB3*#X13`C>4&H"K@$#"-Y0J@DN`*(*#A
MT*'-X0A`H.&(@J#A"*"*X2"!H.$!CXCA"5"@X0!OH.$AD:#A``"@XP`0H.,*
M()+@^`#-X?`!S>$&`(CA"!")X0"PH./X`\WAHAV@X0@0C>6+,J#A%#"-Y0*@
MH.$N/HWB"""=Y=``P^&+,H+A"#"-Y10PG>7H8)_EJCV#X10PC>5`,)WE!@"0
MX/"BS>$#H)#@V`/-X=@BS>$D@:#A!8^(X0`@(N`"`*#AV"7-X01OH.$`("+@
M`@"@X=`BS>&CS:#A@C*@X1`PC>4`,*#A`P":X`S`C>4`(*#AV*#-X=`!S>$`
MH(KA"@"2X`:@B.'0A<WA*#"=Y=!"S>$#@)C@V"3-X3C`G>4`D*#C`D"4X-`C
MS>$$8*#AT$#-X0P@DN``,*/B`$"4X-@!S>'X(,WA!B"@X=A@S>$*`)#@`#"@
MXP!PH.,`4*#C`!"@X_""SN'X(,[A^&'.X?!`SN'P`<[AN]^-XO"/O>C6P6+*
M``!0XQ[_+P'X0RWIK#"?Y0"0D^4``%GC)@``"@!0T.4]`%7C``!5$P%0H!,`
M4*`#$P``&@!`F>4``%3C#@``"@&`H.$`<*#A"6"@X00`H.$'$*#A!2"@X2GO
M_^L``%#C`@``&@4PU.<]`%/C"P``"@1`MN4``%3C\___&@0`H.'X@[WH`%"@
MX0$P]>4]`%/C``!3$_O__QH%4&#@Y/__Z@9@:>`!`(7B1F&@X0!@B.4``(3@
M^(.]Z`D`H.'X@[WH\+H"`#!`+>D`0*#A4%"?Y0S03>($`*#A!!"-XL?__^L`
M`%#C#```"@00G>4`()7E`3&"X`3`D^4``%SC`<&"Y_/__PH$,(/B!""SY0``
M4N,$(`/E^___&NW__^H,T(WB,("]Z/"Z`@#P3RWI`4"@X0`PT>4,T$WB`%"@
MX3T`4^,!0($"!`"@X9SN_^L$$(WB`&"@X04`H.&H___K`)!0XCD```J5[O_K
M``!6X3```)H$<)WEA(&?Y0=QH.$`$-7E/0!1XP``41,!$*`3`!"@`P4```H%
M$*#A`3#QY3T`4^,``%,3^___&@$09>`"`(;B`0"`X`!@F.5N[O_K/#&?Y0``
M4.,'`(;G2@``"@`@D^4$$)WE`##5Y0%0A>(!$9+G``!3XST`4Q,`,,'E!@``
M"@$@@>(!,-7D`A"@X0``4^,]`%,3`3#"Y/G__QH!(*#A/3"@XP`PP>4!,-3D
M``!3XP$PXN7[__\:``"@XPS0C>+PC[WH`2!)X@$PU.0``%/C`3#BY?O__QKV
M___JK("?Y0"@F.4`()KE``!2XR(```H*,*#A!""SY0&0B>(``%+C^___&@(0
MB>(!$:#A@#"?Y0`@D^4``%+C"@``"@H`H.$4[O_K``!0XP``B.45```*"7&@
MX0$PB>(`(*#C`R&`YP20C>6P___J`2"@XP$`H.$`((/E*^[_ZP"P4.()```*
M"7&@X0H0H.$'(*#AVNW_ZPL`H.$`L(CE[?__Z@*0H.$($*#CX/__Z@``X./*
M___J\+H"`""[`@#P0"WI`$!0XG303>("```*`##4Y0``4^,!```:=-"-XO"`
MO>@+[O_K`&!0XOK__PH&`*#A8>[_ZP`P4.(34(/B!`"@X2<```H3(-/E+@!2
MXQL```H7[O_K`'"@X04`H.$4[O_K``"'X`(`@.+_[?_K`1"@XP`@X..(,)_E
M,`"-Z`!PH.$:[O_K!Q"@X0,`H.,(((WB5>[_ZP$`<.,'`*#A`P``"A@PG>4/
M.@/B`0E3XQ(```K&[?_K!P"@X:/M_^O:___J%"#3Y0``4N/7__\*+@!2X][_
M_QH5,-/E``!3X]+__PK:___J!@"@X4[N_^L$`*#AI.W_ZW30C>+P@+WHOO__
MZ^O__^K\>`$`<$`MZ0A!G^4``)3E1N[_ZX`PD.4``)3E!&"3Y4+N_^ME4-#E
M``"4Y3_N_^M_4`7B!#"0Y;`QT^&#.Z#A(UB%X;)0QN$``)3E-^[_ZX`PD.4`
M`)3E!%"3Y3/N_^NT$)_E`""@X]GM_^L<`(7E``"4Y2WN_^N`,)#E``"4Y010
MD^4I[O_KX#20Y0``E.4@,(7E)>[_ZX`PD.4``)3E!%"3Y2'N_^O\,)#E``!3
MXP,```H``)3E'.[_Z_PPD.5P,)/E)#"%Y0``E.47[O_K`%"@XX`PD.4``)3E
M!#"3Y2A0@^41[O_K@#"0Y0``E.4$,)/E&%"#Y0SN_^N`,)#E``"4Y01`D^4(
M[O_K&#*0Y2PPA.5P@+WH`+L"``Q\`0`X0"WI`%"@X6Q`G^4``)3E_NW_ZP40
MH.%"+X#B`P"@X_3M_^L``%#C`0``"@``H.,X@+WH``"4Y?3M_^L8,9#E#SH#
MX@$)4^,%```*``"4Y>[M_^L8,9#E#SH#X@H*4^/Q__\:!0"@X0(0H..][?_K
M$`]OX:`"H.$X@+WH`+L"`/!`+>D!VDWBS%"?Y0S03>(!RHWB`#"5Y03`C.(`
M8*#A`7"@X;0`G^4$$(WBL""?Y0`PC.5([?_K``!0XQX``-H!0$#B"#"-X@3`
M@^`$(%SE``!2XQ8```H`0*#A!`"-XB\0H.,$(*#AF^W_ZP``4.,1```*;#"?
MY0``D^7#[?_K!A"@X00@C>($,*#AI.W_ZP$ZC>($,(/B`""3Y0`PE>4#`%+A
M"P``&@':C>(,T(WB\("]Z```5./G__\:)#"?Y0``D^6Q[?_K!A"@X0<@H.$>
M[?_K[?__Z@WM_^OXN@(`!'D!`/\/````NP(`'#"?Y1!`+>D``)/EI.W_ZQ`0
MG^40()_E$#"?Y1!`O>A7[?_J`+L"`!1Y`0#P%0$`@'@!`!!`+>D(T$WB-$"?
MY0``E.66[?_K[/__ZP``E.63[?_K(#"?Y0`@H.,$((WE`#"-Y100G^44()_E
M7.W_ZPC0C>(0@+WH`+L"``Q\`0`P>0$`L',!`'!`+>D"VDWBS&"?Y2#03>("
M*HWB`#"6Y1P@@N(`,(+E%^W_Z[0PG^44((WB"""-Y00PC>4!$*#CI""?Y:0P
MG^4``(WE"`"=Y2+M_^L``%#C'```N@$ZC>(@,(/B"#!#X@@`G>4#$*#A`2J@
MXPPPC>7<[/_K`%!0XA(``+H!`(7B\^S_ZP!`4.(0```*#!"=Y04@H.&L[/_K
M!`"@X0`PH.,%,,3G`CJ-XAPP@^(`()/E`#"6Y0,`4N$&```:`MJ-XB#0C>)P
M@+WH``"@X_3__^H$`*#A\O__ZK#L_^OXN@(`5'D!``$0``!(>0$`P___ZO!/
M+>D!VDWBN#&?Y1S03>(!*HWB`#"3Y10@@N(`0*#A`6"@X:`!G^40$(WB`#""
MY>W]_^LO$*#C`%"@X00`H.'?[/_K``!0XPT```I\`9_E!!"@X2[^_^L$`*#A
M`3J-XA0P@^(`()/E6#&?Y0`PD^4#`%+A4@``&@':C>(<T(WB\(^]Z`0`H.''
M[/_K0!&?Y0"0H.$&`*#A_.S_ZP"P4.+I__\*+'&?Y2R!G^4LH9_E+&&?Y0`P
MV^4``%/C!["@`0``5>,$```*!0"@X0L0H.%,[/_K``!0XR@```H+`*#AL>S_
MZP`PB^`!,%/E+P!3XP<``!H!,$#B`S"+X`#`H.,`P,/E`1!SY0$`0.(O`%'C
M^O__"@$PB>(``(/@"`!0X<G__\H!$*#C`2J@X[0PG^4`L(WE!*"-Y0A`C>44
M`(WBJ.S_ZP``EN7W[/_K%!"-XD(O@.(#`*#CX>S_ZP``4.,%```:``"6Y>_L
M_^L8,9#E#SH#X@()4^,&```*``"@XTP0G^7![/_K``!0XP"PH.''__\:K/__
MZA0`C>(!$*#CM^S_ZP``4./S__\:%!"-XA@`G^76_?_K%`"-XH_L_^NE___J
M.>S_Z_BZ`@!<>0$`:'D!`'AY`0!8>0$`_P\``(1Y`0``NP(`?'D!```PT.4`
M`%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_+^$X0"WI`$!0XBL`
M``H`4-3E``!5XR@```I>[/_K`0!`X@`PA.`#`%3A"P``*@`@U.<O`%+C*0``
M&@$@0^(#``#J`!#2Y0$@0N(O`%'C(P``&@0`4N$",*#A^/__&@,`5.$3```*
M`3!#X@,``.H`$-/E`3!#XB\`4>,"```:`P!4X0,@H.'X__\Z`B!DX`(P@N(!
M"E/C#P``B@00H.$!((+B`3J@XV@`G^7XZ__K8`"?Y3B`O>@O`%7C$@``&@(`
MH.,B[/_K``!0XP(```HN,*#CL##`X3B`O>@``*#C.("]Z`$@0^(#``#J`!#2
MY0$@0N(O`%'CVO__"@(`5.$",*#A^/__.M3__^H(`)_E.$"]Z#7L_^HDNP(`
MA'D!`#!`+>DTT$WB4.&?Y0C`C>),09_E#P"^Z`!0E.4/`*SH#P"^Z"Q0C>4`
MX)[E#P"LZ#`!G^6PX,SA4/W_ZR@!G^5._?_K)`&?Y4S]_^L@`9_E2OW_ZQP!
MG^5(_?_K&`&?Y4;]_^L4`9_E1/W_ZQ`!G^5"_?_K#`&?Y4#]_^L(`9_E/OW_
MZP0!G^4\_?_K``&?Y3K]_^O\`)_E./W_ZP00C>+T`)_E!/W_ZP`04.(!```*
MT`"?Y4K]_^L$$(WBW`"?Y?W\_^L`$%#B`0``"M``G^5#_?_K!!"-XL@`G^7V
M_/_K`!!0X@H```J0`)_E//W_ZX``G^6P$)_E.?W_ZRP@G>4`,)3E`P!2X1,`
M`!HTT(WB,("]Z`00C>*0`)_EYOS_ZP`04.("```*5`"?Y2S]_^ON___J&0"-
MXG00G^4*(*#C'NS_ZP``4./H__\:(Q"-XBP`G^4B_?_KY/__ZH?K_^N,>`$`
M^+H"`(AY`0"4>0$`G'D!`*AY`0"P>0$`P'D!`%QY`0#,>0$`V'D!`.1Y`0!H
M>0$`\'D!`/QY`0`(>@$`''H!`#!Z`0`\>@$`;'H!`$QZ`0!@>@$`$$`MZ0C0
M3>)$0)_E``"4Y0$`<.,!```*"-"-XA"`O>@P`)_E!!"-XK7\_^L``%#C!```
M"@``T.4``%#C,`!0$P$`H!,``*`#``"$Y0C0C>(0@+WHZ+H"`,QY`0`(0"WI
M-^O_ZS#K_^L``%#C``"0%0B`O>CP0RWI`&"@X=3@G^4TT$WB%,"-X@\`ON@/
M`*SH!P">Z!1`G>4``%3C!P",Z!<```JP@)_E%%"-X@4``.H7Z__K``!0XQ,`
M``H$0+7E``!4XPX```H0$(WB!`"@X8O\_^L&$*#A`'!0X@(```H`,-?E``!3
MX_#__QH$`*#A!A"@X<S\_^L$0+7E``!4X_#__QHTT(WB\(.]Z`8`H.%KZ__K
M`)"@X0<`H.%HZ__K``")X`(`@.)3Z__K0`&-Z`APC>4!$*#C`"#@XQPPG^4`
MD*#A;>O_ZP0`H.$)$*#AM?S_Z]C__^JP>`$`>'D!`'QY`0!X.9_E\$\MZ0!0
MH.&!W$WB!P"3Z#S03>)`P(WB#$"#X@<`C.@DP(/B#P"TZ%C@C>),8(WB#P"N
MZ`,`E.A`.9_E`P".Z`<`G.B!S(WB`#"3Y33`C.('`(;H/!"-XB0)G^4`,(SE
M3?S_ZP!`4.("```*`##4Y0``4^,!`0`:G?__ZP!`4.),8(T"1P``"@0`H.$R
MZ__K@`"@X0$`@.(=Z__K`##4Y0``4^,`@*#A`&"@$0D```H`,(WE!@"@X<@X
MG^4!$*#C`"#@XS/K_^L!,/3E`F"&X@``4^/U__\:6`"=Y0``4.-80(T2`P``
M&A```.H$`+3E``!0XPT```H\$(WB)OS_ZP!@4.+X__\*`##6Y0``4^/U__\*
M;/W_ZP``4./R__\*!@"@X2'K_^L`D%#B*0``&D!`G>4``%3C)0``"@`PU.4`
M`%/C`6"@$PD``!H@``#J3C^-X@8Q@^#X0!/E``!4XQL```H`,-3E`6"&X@``
M4^,7```*!`"@X5/]_^L``%#C\O__"@0`H.$(Z__K``!0X^[__PH`D*#A#@``
MZ@/K_^L``%#CO```&@0`EN0``%#CM@``"CP0C>+W^__K`#!0XOC__PH`,-/E
M``!3X_7__PKQ___J`)"@XPD`H.'>ZO_KI'>?Y0!`H.$(`*#AVNK_ZP``A.`!
M2X#B!$"$X@0`H.'#ZO_KA#>?Y0$0H.,(,(WE`"#@XW@WG^4`D(WE#("-Y01P
MC>4`8*#AVNK_ZP8`H.$'':#CX^K_ZP$`<.,:```*4(>?Y0``F.4CZ__K!A"@
MX4(O@.(#`*#C&>O_ZP``4.,?```*,">?Y0`PE>4!$*#C`&"-Y0``DN4@)Y_E
MX^K_ZP``H..!/(WB-#"#X@`@D^7H-I_E`#"3Y0,`4N&U`0`:@=R-XCS0C>+P
MC[WHMNK_ZP`@D.41`%+CX/__"M@6G^4`,)7E`&"-Y0``D>4$((WE`1"@X\@F
MG^7,ZO_K``"@X^?__^H``)CE^^K_ZQ@QD.4/.@/B`0E3X]G__QH``)CE]>K_
MZR"1D.4SZO_K``!9X=/__QH``)CE[^K_ZQ@QD.6#.Z#A#@)3X\W__QH$`*#A
M=^K_ZSP0C>(`0*#A9`:?Y97[_^L``%#CB`$`"@"`E>66ZO_K`!"@X0@`H.&3
M_?_K`(!0XH$!``H(`*#A>NK_ZP,`4.,`D*#A"P``V@0`0.(``(C@(!:?Y0KJ
M_^L``%#C!0``&@0`6>,P`0`*"9"(X`4P6>4O`%/C+`$`"KG^_^L`$%#B!```
M&@@`H.%1ZO_K`#!0XB`PC>4U```:W!6?Y=P%G^6Z^__K6>K_Z]25G^7``(WH
M#)"-Y0$0H.,`(.#CQ#6?Y0"`H.,(`(WE!`"@X63J_^L.``#J7^K_ZP`PD.41
M`%/C$```&DGJ_^L!@(CB#("-Y<``C>@0D(WE!2"@X0$0H..$-9_E"`"-Y00`
MH.%4ZO_K!`"@X0<=H.-=ZO_K`0!PXP!0H.'J__\*!@"@X>/I_^L$$*#A%`6?
MY93[_^L$`*#AI/[_ZP0`H.&`___JH?[_ZP0`H.%(ZO_K?/__ZBQ%G^4-`*#C
M_O[_Z@!`H.'X_O_J`E"@XP`PX.,1(.#C`%"-Y0?J_^M-'XWB(`"=Y08@H./!
MZ?_K-#'=Y0``4^,"```:-3'=Y4,`4^,"`0`*`%"@XP`@H.,`,*#C`%"-Y2``
MG>7WZ?_KR*2?Y<@$G^4`$*#CQ"2?Y0"PH.,`,*#C\`O-X;B$G^6X!)_E^*S-
MX>B@C>+X*\WA`)"@XP`@H.,`,*#C`!"@XR1`C>4*0*#A*%&-Y?",S>'P#<WA
M^"W-X?`NS>$H8(WE+'"-Y2``G>5-'XWB`BF@XYCI_^L`4%#B5```VM@MS>&%
M8:#A`)"@XP*`EN`)`%/A"`!2`04`H.'%'Z#AT"[-X0$``)H!()+B`#"CXJ#.
MH.&!P8SAH1Z@X1C`C>4<$(WEV*'-X2@!G>7XC<WA`J":X`.PJ^`*(*#A"S"@
MX0``4./P+LWA-P``"D`P8.(#`%7A`X"@H06`H+&P,(WB.`"`X@``@^`((*#A
M31^-XH#I_^LH,9WE`S"(X$``4^,H,8WES___&DT_C>*P`(WB!5!HX`B`@^`&
MZ__K/P!5XQH``-I`L(CB!9"@X02@H.%`0$OB"N"@X0``E.4$$)3E"""4Y0PP
ME.4.P*#A$$"$X@L`5.$/`*SH#."@X?7__QI`D$GBL`"-XO+J_^L_`%GC0+"$
MXNW__\I`4$7B"D"@X24SH.$!((/B`U-%X`*#B.`($*#A!`"@X04@H.%(,*#C
M?NG_ZRA1C>6F___J38^-XMG__^H@`(WBT0"0Z/CI_^O84)WE3C^-XG\0X..E
M(:#A/R`"X@(P@^`!`(+B.`!0XU`00^4Y`(+BL#"-XN"`G>4``(/@8@``RC<@
M8N(`$*#CKNG_ZRCHH.$HQ*#A)1R@X24HH.$E-*#A*)R@X;``C>(C@<WE)U'-
MY2"1S>4AX<WE(L'-Y201S>4E(<WE)C'-Y;SJ_^NPX)WEN`"=Y<`0G>4NB*#A
M+CR@X7/@S>4NY*#A<N#-Y2#LH.'(()WE=P#-Y73@S>4@Z*#A(`2@X=#`G>5V
M`,WE(0R@X7@`S>4A"*#A=>#-Y7L0S>4B[*#A(12@X7D`S>5_(,WE(@B@X2(D
MH.&$H(WB>A#-Y7T`S>4L'*#A+`B@X7X@S>4L)*#A<8#-Y0I0H.%P,,WE<("-
MXH.0C>)\X,WE@\#-Y8`0S>6!`,WE@B#-Y0```.H!,/CE`#"-Y04`H.$!$*#C
M`"#@XV`QG^5;Z?_K"0!8X0)0A>+U__\:?#&?Y0#`H.,,,(WEP`2-Z`0`H.$!
M$*#C`"#@XX0QG^6LP,WE3NG_Z_[^_^H$4)7E``!5X\_^_PH%`*#A.>G_ZP,`
M4./+_O^:!`!`X@``A>!4$9_ERNC_ZP``4.,%@*`!Q/[_ZC\@8N(`$*#C2^G_
MZ[``C>)GZO_K`#"@X^@PC>7L,(WE\#"-Y?0PC>7X,(WE_#"-Y0`QC>4$,8WE
M"#&-Y0PQC>40,8WE%#&-Y1@QC>4<,8WEBO__ZC8QW>5!`%/C^?[_&C<QW>5#
M`%/C]O[_&C@QW>5(`%/C\_[_&CDQW>5%`%/C\/[_&@!0C>4@4)WE`##@XP4`
MH.$Y(.#CZ.C_ZTT?C>(%`*#A*2"@XZ+H_^ML,)_E32^-X@@@C>4,,(WEP`"-
MZ`0`H.$!$*#C`"#@XW`PG^4*Z?_KNO[_Z@"`E>5[_O_JN.C_Z\QX`0#XN@(`
M7'D!`'AZ`0"$>0$`C'H!`(!Z`0``NP(`"+L"`!1[`0"4>@$`8'P!`-!Z`0!L
M>@$`S'D!``Q\`0#P>@$``'L!`'!Z`0!V5#(0`2-%9XFKS>_^W+J8\.'2P^!Z
M`0#8>@$`\$\MZ0S03>)4@Y_E``"8Y3CI_^L!,*#C!!"-XF$PP.5``Y_EX_G_
MZP``4.,"```*`##0Y3$`4^.!```*KOS_ZP``F.4KZ?_K'!.?Y0$@H.,+,*#C
MN^C_ZQ!CG^4``%#C+@``"A`@D.7T/Q;E`0!3XQB0DN4I``#:Y**?Y0!0H.,!
M0*#C"0``ZA`0DN4+`*#A3^C_Z_0_%N4``%#C'```&@%`A.($`%/A`5"%XA@`
M`-H``)CE#^G_ZPD0H.$%(*#A`#"@X^?H_^L`<%#B#P``"@`@E^68,I_E\!\6
MY0@`DN4`,`/@`0M3XP2QD>?E__\*``":Y?_H_^L`$)?E`""@XP(PH.-TZ/_K
M`!"@X=[__^KT/Q;E`2!#X@4`4N$\```*``"8Y?/H_^M($I_E`2"@XP,PH..#
MZ/_K)%*?Y0!`4.(*```*``"5Y>KH_^L0,)3E)"*?Y0`0D^56Z/_K$#"4Y0`P
MD^4(,)/E`043XVX``!H``)CEW^C_ZP`2G^4!(*#C`S"@XV_H_^O409_E`%!0
MX@H```KH`9_E!!"-XH7Y_^L`<%#B``"4Y4<```K1Z/_K$#"5Y0<@H.$`$)/E
M/>C_ZP``F.7+Z/_K`#"@XP00C>*,D9_EE'&?Y6$PP.6D`9_E=/G_ZP``4.,`
M0*#A[`\&Y1<```H'':#C>>C_ZP$P@.(1`%#C`0!3$T\``(H,T(WB\(^]Z`$`
M4^/`___:`4"@XP``F.6SZ/_K"1"@X?KG_^OT/Q;E`4"$X@0`4^'W___*MO__
MZ@$PT.4``%/C>___"GG__^KP#Q?E[OS_ZP``4./L#P?E-@``"A`@E>4`,9_E
M`""2Y0@0DN4!,`/@`0M3XR$``!H0`)+E\$\6Y000H.'GY__K$#"5Y=0@G^4`
M0)3E`,"3Y0@PG.4#(`+@`0M2XP!@H.$+```:$""<Y000H.$&,*#AP`"?Y3SH
M_^N)Z/_K$""5Y?`_%N4``)+E`!"3Y:#Z_^NU___J``"8Y8'H_^L0$)7E`""@
MXP(PH.,`$)'E]>?_ZP`@H.'K___J``"9Y7CH_^L0$)7E!""@X0(PH.,`$)'E
M[.?_Z];__^H``)7E<.C_ZQ`PE.4`$)/E-.C_ZXK__^I$`)_E'.C_Z_`?%^4`
M,*#A!""@X0`0D>4P`)_E%NC_ZP"[`@"P>0$`:'L!`!C;`@``!"``<'L!`'1[
M`0!\>P$`:'D!`%QY`0"D>P$`@'L!`,Q[`0`X0"WI`%"@X8[[_^L`,-#E`$"@
MX0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:./S_ZP``4.,``%43
M.("]"``PU>4``%/C.("]"`0`H.$4$)_E=.?_ZP``5.$X@+T8!0"@X3A`O>BM
M^?_JC'H!`!!`+>DD0)_E``"4Y3;H_^L`$.#CMN?_ZP``E.4RZ/_K#!"?Y0`@
MH.,00+WH&>C_Z@"[`@!\7P$`##"?Y0,PC^```%/C`#"3%8OG_^KD0@$`^$,M
MZ0!PH.%,8)_E3%"?Y09@C^`%4(_@!F!EX`&`H.$"D*#A2.?_ZT9AL.'X@[T(
M!%!%X@!`H.,!0(3B!#"UY0<`H.$($*#A"2"@X3/_+^$&`%3A]___&OB#O>AX
M0`$`<$`!`![_+^$(0"WI"("]Z`$``@!P97)L>'-I+F,```!?7T5.5E]005)?
M0TQ%04Y?7R`@("`@("`@("`@("`@(`````!`?`$`4'P!`%A\`0!@?`$`:'P!
M`'Q\`0``````.'P!`%AY`0``````,'H!`#1Z`0`L?`$`8'D!`#1\`0``````
M&'P!`"!\`0``````)7,O)7,````O<')O8R]S96QF+V5X90``1'EN84QO861E
M<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"3T]4`````"]P
M<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!23T=.04U%````
M`#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"`%!%4DPU3U!4
M`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#
M3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]!4D=#`````%!!
M4E]!4D=67S```%!!4E]'3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$
M25(```!005)?5$U01$E2``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#
M3$5!3@````!005)?0TQ%04X]```Q````4UE35$5-```E,#)X`````"5S)7,E
M<R5S`````'!A<BT`````)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@<W5B9&ER
M96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``<&%R;``````N<&%R````
M`"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M
M)74E<P`````E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E
M("AP;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*
M``!!4D=6`````!@```!P97)L`````#````!5;F%B;&4@=&\@8W)E871E(&-A
M8VAE(&1I<F5C=&]R>0`````E<SH@97AE8W5T:6]N(&]F("5S(&9A:6QE9"`H
M97)R;F\])6DI"@``)7,Z(&-R96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B
M9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@`````M90``+2T``%53
M15(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M<`````!,1%],24)2
M05)97U!!5$@`3$E"4$%42`!,24)205)97U!!5$@`````1%E,1%],24)205)9
M7U!!5$@```!32$Q)0E]0051(``!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*:68@
M*&5X:7-T<R`D14Y6>U!!4E]!4D=67S!](&%N9"`D14Y6>U!!4E]!4D=67S!]
M("D@>PI`05)'5B`](&UA<"`D14Y6>R)005)?05)'5E\D7R)]+"`H,2`N+B`D
M14Y6>U!!4E]!4D=#?2`M(#$I.PHD,"`]("1%3E9[4$%27T%21U9?,'T["GT*
M96QS92!["F9O<B`H:V5Y<R`E14Y6*2!["F1E;&5T92`D14Y6>R1??2!I9B`O
M7E!!4E]!4D=67R\["GT*?0IM>2`D<75I970@/2`A)$5.5GM005)?1$5"54=]
M.PIM>2`E0V]N9FEG(#T@*`IP871H7W-E<"`@("`]/B`H)%Y/(#U^("]>35-7
M:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@*"1>3R`]?B`O7B@_
M.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G*2P*7V1E;&EM("`@
M("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@)R\G*2P**3L*
M7W-E=%]P<F]G;F%M92@I.PI?<V5T7W!A<E]T96UP*"D["FUY("@D<W1A<G1?
M<&]S+"`D9&%T85]P;W,I.PI["FQO8V%L("1324=[7U]705).7U]](#T@<W5B
M('M].PIO<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*8FEN;6]D
M92A?1D@I.PIM>2`D8G5F.PIS965K(%]&2"P@+3@L(#(["G)E860@7T9(+"`D
M8G5F+"`X.PIL87-T('5N;&5S<R`D8G5F(&5Q(")<;E!!4BYP;5QN(CL*<V5E
M:R!?1D@L("TQ,BP@,CL*<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M
M,3(@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP9FEL92@D97AT
M+"`D8W)C*3L*:68@*"1O=70I('L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U
M="`D8G5F.PIC;&]S92`D;W5T.PIC:&UO9"`P-S4U+"`D9FEL96YA;64["GT*
M)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N86UE
M.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L;&YA
M;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N9"!D
M969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2`B)$5.
M5GM005)?5$5-4'TO)&)A<V5N86UE)&5X="(["F]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PIO<&5N(&UY("1O=70L("<^)RP@)&9I;&5N86UE(&]R(&1I
M92`D(3L*8FEN;6]D92@D;W5T*3L*<')I;G0@)&]U="`D8G5F.PIC;&]S92`D
M;W5T.PI]"F5L<V4@>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2
M.CI(96%V>3HZ36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B
M=68L"F-R8R`]/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D
M(%]&2"P@)&)U9BP@-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L
M9BP@)&UO9'5L92D@/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D
M;6]D=6QE.PIM>2`D9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD
M;6]D=6QE?2!\?"!D;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I
M<F5?;&ES="D@>PIN97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]
M("1?.R!L87-T.PI]"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L
M;V%D97(O)&9I;&5N86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ
M1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R
M:6YT("1F:"`D9FEL96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E
M='5R;B`D9F@["GT*96QS92!["FUY("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I
M;&4H)RYP;2<L("1F:6QE;F%M92T^>V-R8WTI.PII9B`H)&]U="D@>PIB:6YM
M;V1E*"1O=70I.PIP<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["F-L;W-E
M("1O=70["GT*;W!E;B!M>2`D9F@L("<\)RP@)&YA;64@;W(@9&EE("0A.PIB
M:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG
M(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR
M97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@
M0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE
M879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H
M:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I
M6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]
M?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*
M<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE
M<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L
M971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D
M8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@
M+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F
M:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@
M(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*
M)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R
M=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF
M="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@
M:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@
M("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM
M<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@
M<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R
M"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@
M+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q
M("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@
M)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU
M;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD
M;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I
M=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]
M"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@
M97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@
M0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD
M8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@
M/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII
M;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD
M8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?
M*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?
M:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/"<L
M("1P87(@;W(@9&EE(")#86YN;W0@9FEN9"`G)'!A<B<Z("0A(CL*8FEN;6]D
M92@D9F@I.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE(")296%D
M("<D<&%R)R!E<G)O<CH@)"$B.PI]"FUY("5E;G8@/2!D;R!["FEF("@D>FEP
M(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2![
M"B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M
M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N*RDD+VUG.PI]"GT["FQO8V%L
M("0O(#T@7#0["FEF("AD969I;F5D("1P87(I('L*;W!E;B!005(L("<\)RP@
M)'!A<B!O<B!D:64@(B0A.B`D<&%R(CL*8FEN;6]D92A005(I.PID:64@(B1P
M87(@:7,@;F]T(&$@4$%2(&9I;&4B('5N;&5S<R`\4$%2/B!E<2`B4$M<,#`S
M7#`P-"(["GT*0W)E871E4&%T:"@D;W5T*2`["FUY("1F:"`]($E/.CI&:6QE
M+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4*"D@?"!)3SHZ1FEL93HZ
M3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@
M9&EE("0A.PIB:6YM;V1E*"1F:"D["B0O(#T@*&1E9FEN960@)&1A=&%?<&]S
M*2`_(%PD9&%T85]P;W,@.B!U;F1E9CL*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(@/2!S8V%L87(@/%]&2#X["FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN
M97<M/F%P<&QY*%PD;&]A9&5R+"`D,"D*?0IF;W)E86-H(&UY("1K97D@*'-O
M<G0@:V5Y<R`E96YV*2!["FUY("1V86P@/2`D96YV>R1K97E](&]R(&YE>'0[
M"B1V86P@/2!E=F%L("1V86P@:68@)'9A;"`]?B`O7ELG(ETO.PIM>2`D;6%G
M:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["FUY("1S970@
M/2`B4$%27R(@+B!U8R@D:V5Y*2`N("(])'9A;"(["B1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*)&UA9VEC("X@)'-E="`N("@G("<@>"`H;&5N9W1H*"0Q
M*2`M(&QE;F=T:"@D<V5T*2DI"GUE9SL*?0HD9F@M/G!R:6YT*"1L;V%D97(I
M.PHD+R`]('5N9&5F.PII9B`H)&)U;F1L92D@>PIR97%U:7)E(%!!4CHZ2&5A
M=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*:6YI=%]I;F,H
M*3L*<F5Q=6ER95]M;V1U;&5S*"D["FUY($!I;F,@/2!S;W)T('L*;&5N9W1H
M*"1B*2`\/3X@;&5N9W1H*"1A*0I](&=R97`@>PHA+T)31%!!3B\*?2!G<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*+UY?/"@N*RDD+R!A;F0@
M+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y<R`E.CH["B1F:6QE<WLD
M7WTK*R!F;W(@=F%L=65S("5)3D,["FUY("1L:6)?97AT(#T@)$-O;F9I9SHZ
M0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*9F]R96%C:"`H<V]R="!K
M97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE*3L*9F]R96%C:"!M>2`D
M9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*96QS:68@*"]>*%Q1)&1I
M<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L("1N86UE*2`]("@D,2P@
M)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R+UM>+UTK+R@N*EM>0V-=
M*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE879Y.CI-;V1U;&5#86-H
M97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]
M"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D
M:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@=6YL97-S(&1E9FEN960@
M)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F
M*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["F]U=',H
M(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D9FEL92`_("1F:6QE+3Y[
M;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@)&-O;G1E;G0["FEF("AR
M968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@
M>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE(")#86XG="!O<&5N("1F
M:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT96YT(#T@/$9)3$4^.PIC
M;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@
M)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T
M8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE
M*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE(BDI.PHD9F@M/G!R:6YT
M*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@
M*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P.'@O)7,B+"!!<F-H:79E
M.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE"BDI.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E;G0I*2D["B1F:"T^<')I
M;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H
M*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY("1M=&EM92`]("AS=&%T
M*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF
M("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD(&]P96XH;7D@)&9H+"`B
M/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H*3L*
M8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M92`N/2`B7#`B('@@*#0Q
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE7VYA;64@+CT@(D-!0TA%
M(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F:"T^<')I;G0H<&%C:R@G
M3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R*2DI.PHD9F@M/G!R:6YT
M*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H;6]D(#`W-34L("1O=70[
M"F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F
M:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF9&]P96XH9FEL96YO*%]&
M2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP+3YR96%D1G)O;49I;&5(
M86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH
M*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ3&EB0V%C:&4L("1Z:7`[
M"B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D>FEP.PHD<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D
M14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI
M('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@
M)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^
M:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.
M86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB
M+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T
M7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I
M;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E
M<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H
M*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET
M(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(BDI.PI](&5L<V4@>PIO
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE
M*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*
M?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*
M9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A
M<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G
M<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q
M=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E
M>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ
M)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D
M<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R
M<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U
M:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I
M8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#
M87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U
M:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER
M92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P
M96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E
M($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E
M<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP.PIR97%U:7)E(%!!4CL*
M<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER
M92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q
M=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E
M<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z
M.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA
M;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@
M4&5R;$E/.CIS8V%L87(@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY
M("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2
M(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI
M('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD
M("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P
M=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E
M9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN
M,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S
M97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U53
M15).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R;F%M
M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG>U]D
M96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T
M;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I
M;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L("(\
M(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D9F@L
M(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K("1F
M:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@<R]<
M,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@+B`D
M8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG97-T
M.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A;"![
M(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*;7D@
M)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/3B!]
M('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?=F5R
M<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L(")B
M(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM>2`D
M9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA9&1F
M:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O;F9I
M9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z
M("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,
M14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D
M(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I
M<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?=&5M
M<&9I;&4@>PIM>2`H)&5X="P@)&-R8RD@/2!`7SL*;7D@*"1F:"P@)&9I;&5N
M86UE*3L*)&9I;&5N86UE(#T@(B1P87)?=&5M<"\D8W)C)&5X="(["FEF("@D
M14Y6>U!!4E]#3$5!3GTI('L*=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL
M96YA;64["G!U<V@@0'1M<&9I;&4L("1F:6QE;F%M93L*?0IE;'-E('L*<F5T
M=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*?0IO
M<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PIB:6YM;V1E*"1F
M:"D["G)E='5R;B@D9F@L("1F:6QE;F%M92D["GT*<W5B(%]S971?<')O9VYA
M;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[
M4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*
M)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E
M>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M
M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#;VYF
M:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O
M<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@>PII
M9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M
M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@>PHD
M<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C
M:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@)$5.
M5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A;F0@
M)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I9WM?
M9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI
M;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H)'!R
M;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@;&%S
M="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D
M96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM?21P
M<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@
M/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_
M(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G
M;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D
M0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA
M;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)
M04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?
M24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%
M04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*9&5L
M971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-4"!#
M3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.5GM0
M05)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#
M3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R("L@
M;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@)'9A
M;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*<F5T
M=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?
M7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@
M>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA
M<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB
M97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD
M;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H
M:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A
M<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B
M)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU;FQE
M<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I
M(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D
M0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I
M(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE
M("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`9&+_?P$`
M````````X!L!`+@;`0```````0````$````!````!0(```$````0`@```0``
M`!H"```!````:0(```$```"\`P```0```.(#```,````6!4!``T```!T>`$`
M&0```)BX`@`;````!````!H```"<N`(`'`````0```#U_O]OE`$!``4```!4
M#`$`!@```%0%`0`*````8@4```L````0````%0`````````#````O+D"``(`
M```H`@``%````!$````7````,!,!`!$```#X$@$`$@```#@````3````"```
M`/[__V^8$@$`____;P,```#P__]OMA$!````````````````````````````
M`````````````````````````````````````*2X`@```````````&05`0!D
M%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05
M`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!
M`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`
M9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D
M%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05
M`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!`&05`0!D%0$`9!4!
M`````````````````/____^(?`$`1T-#.B`H4F%S<&)I86X@-"XY+C$M-"D@
M-"XY+C$`1T-#.B`H4F%S<&)I86X@-"XX+C,M-"D@-"XX+C,`03````!A96%B
M:0`!)@````4V``8&"`$)`0H"$@03`10!%0$7`Q@!&0$:`AL#'`$B`0`N<VAS
M=')T86(`+FEN=&5R<``N;F]T92Y!0DDM=&%G`"YN;W1E+F=N=2YB=6EL9"UI
M9``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YG;G4N=F5R<VEO;@`N9VYU
M+G9E<G-I;VY?<@`N<F5L+F1Y;@`N<F5L+G!L=``N:6YI=``N=&5X=``N9FEN
M:0`N<F]D871A`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF
M:6YI7V%R<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM
M96YT`"Y!4DTN871T<FEB=71E<P``````````````````````````````````
M``````````````````````L````!`````@```#0!`0`T`0``&0``````````
M`````0`````````3````!P````(```!0`0$`4`$``"````````````````0`
M````````(0````<````"````<`$!`'`!```D```````````````$````````
M`#0```#V__]O`@```)0!`0"4`0``P`,```4`````````!`````0````^````
M"P````(```!4!0$`5`4````'```&`````0````0````0````1@````,````"
M````5`P!`%0,``!B!0`````````````!`````````$X```#___]O`@```+81
M`0"V$0``X`````4``````````@````(```!;````_O__;P(```"8$@$`F!(`
M`&`````&`````P````0`````````:@````D````"````^!(!`/@2```X````
M!0`````````$````"````',````)````0@```#`3`0`P$P``*`(```4````,
M````!`````@```!\`````0````8```!8%0$`6!4```P```````````````0`
M````````=P````$````&````9!4!`&05``!0`P`````````````$````!```
M`((````!````!@```+@8`0"X&```O%\`````````````"`````````"(````
M`0````8```!T>`$`='@```@```````````````0`````````C@````$````"
M````?'@!`'QX```00``````````````$`````````)8````!``!P@@```(RX
M`0",N```"`````T`````````!`````````"A`````0````(```"4N`$`E+@`
M``0```````````````0`````````JP````X````#````F+@"`)BX```$````
M```````````$`````````+<````/`````P```)RX`@"<N```!```````````
M````!`````````##`````0````,```"@N`(`H+@```0```````````````0`
M````````R`````8````#````I+@"`*2X```8`0``!@`````````$````"```
M`-$````!`````P```+RY`@"\N0``)`$`````````````!`````0```#6````
M`0````,```#@N@(`X+H``!````````````````0`````````W`````@````#
M````\+H"`/"Z``!$$``````````````(`````````.$````!````,```````
M``#PN@``/````````````````0````$```#J`````P``<```````````++L`
M`#$```````````````$``````````0````,``````````````%V[``#Z````
M```````````!``````````$```!D%0$`````````#``$````=!4!````````
:``P``0```'@5`0`````````,```D80`D9```
